@@ -34,19 +34,23 @@
 #include <QFileDialog>
 #include <QDialog>
 #include <QDialogButtonBox>
-#include <QMimeDatabase>
 #include <QMimeType>
 #include <QTemporaryFile>
 
+#include <kio_version.h>
 #include <KLocalizedString>
 #include <KIconLoader>
 #include <KSqueezedTextLabel>
+#if KIO_VERSION >= 0x054700 // >= 5.71.0
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
+#else // < 5.71.0
 #include <KRun>
-#include <kio_version.h>
+#endif // KIO_VERSION >= 0x054700
 
-#include "preferences.h"
-#include "fileinfo.h"
-#include "fieldlistedit.h"
+#include <Preferences>
+#include <FileInfo>
+#include "field/fieldlistedit.h"
 #include "logging_gui.h"
 
 class PDFListModel;
@@ -156,7 +160,11 @@ void PDFItemDelegate::updateItemWidgets(const QList<QWidget *> widgets, const QS
     /// determine some variables used for layout
     const int margin = option.fontMetrics.height() / 3;
     const int buttonHeight = option.fontMetrics.height() * 6 / 3;
+#if QT_VERSION >= 0x050b00
+    const int maxTextWidth = qMax(qMax(option.fontMetrics.horizontalAdvance(i18n("Use URL only")), option.fontMetrics.horizontalAdvance(i18n("Ignore"))), qMax(option.fontMetrics.horizontalAdvance(i18n("Download")), option.fontMetrics.horizontalAdvance(i18n("View"))));
+#else // QT_VERSION >= 0x050b00
     const int maxTextWidth = qMax(qMax(option.fontMetrics.width(i18n("Use URL only")), option.fontMetrics.width(i18n("Ignore"))), qMax(option.fontMetrics.width(i18n("Download")), option.fontMetrics.width(i18n("View"))));
+#endif // QT_VERSION >= 0x050b00
     const int buttonWidth = maxTextWidth * 3 / 2;
     const int labelWidth = option.rect.width() - 3 * margin - KIconLoader::SizeMedium;
     const int labelHeight = option.fontMetrics.height();//(option.rect.height() - 4 * margin - buttonHeight) / 2;
@@ -200,7 +208,7 @@ void PDFItemDelegate::updateItemWidgets(const QList<QWidget *> widgets, const QS
             radioButton->move(option.rect.width() - margin - (3 - i) * (buttonWidth + margin), option.rect.height() - margin - h);
             radioButton->resize(buttonWidth, h);
             bool ok = false;
-            radioButton->setChecked(i + FindPDF::NoDownload == index.data(PDFListModel::DownloadModeRole).toInt(&ok) && ok);
+            radioButton->setChecked(i + static_cast<int>(FindPDF::DownloadMode::No) == index.data(PDFListModel::DownloadModeRole).toInt(&ok) && ok);
         }
     }
 }
@@ -209,7 +217,11 @@ QSize PDFItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModel
 {
     /// set a size that is suiteable
     QSize size;
+#if QT_VERSION >= 0x050b00
+    size.setWidth(option.fontMetrics.horizontalAdvance(i18n("Download")) * 6);
+#else // QT_VERSION >= 0x050b00
     size.setWidth(option.fontMetrics.width(i18n("Download")) * 6);
+#endif // QT_VERSION >= 0x050b00
     size.setHeight(qMax(option.fontMetrics.height() * 16 / 3, static_cast<int>(KIconLoader::SizeMedium))); ///< KIconLoader::SizeMedium should be 32
     return size;
 }
@@ -231,21 +243,26 @@ void PDFItemDelegate::slotViewPDF()
             QMimeType mimeType = FileInfo::mimeTypeForUrl(tempUrl);
             const QString mimeTypeName = mimeType.name();
             /// Ask KDE subsystem to open url in viewer matching mime type
-#if KIO_VERSION < 0x051f00 // < 5.31.0
-            KRun::runUrl(tempUrl, mimeTypeName, itemView(), false, false, url.toDisplayString());
-#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+#if KIO_VERSION < 0x054700 // < 5.71.0
             KRun::runUrl(tempUrl, mimeTypeName, itemView(), KRun::RunFlags(), url.toDisplayString());
-#endif // KIO_VERSION < 0x051f00
+#else // KIO_VERSION < 0x054700 // >= 5.71.0
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(tempUrl, mimeTypeName);
+            job->setUiDelegate(new KIO::JobUiDelegate());
+            job->setSuggestedFileName(url.toDisplayString());
+            job->start();
+#endif // KIO_VERSION < 0x054700
         } else if (url.isValid()) {
             /// Guess mime type for url to open
             QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
             const QString mimeTypeName = mimeType.name();
             /// Ask KDE subsystem to open url in viewer matching mime type
-#if KIO_VERSION < 0x051f00 // < 5.31.0
-            KRun::runUrl(url, mimeTypeName, itemView(), false, false);
-#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+#if KIO_VERSION < 0x054700 // < 5.71.0
             KRun::runUrl(url, mimeTypeName, itemView(), KRun::RunFlags());
-#endif // KIO_VERSION < 0x051f00
+#else // KIO_VERSION < 0x054700 // >= 5.71.0
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimeTypeName);
+            job->setUiDelegate(new KIO::JobUiDelegate());
+            job->start();
+#endif // KIO_VERSION < 0x054700
         }
     }
 }
@@ -258,7 +275,7 @@ void PDFItemDelegate::slotRadioNoDownloadToggled(bool checked)
     QModelIndex index = focusedIndex();
 
     if (index.isValid() && checked) {
-        m_parent->model()->setData(index, FindPDF::NoDownload, PDFListModel::DownloadModeRole);
+        m_parent->model()->setData(index, static_cast<int>(FindPDF::DownloadMode::No), PDFListModel::DownloadModeRole);
     }
 }
 
@@ -270,7 +287,7 @@ void PDFItemDelegate::slotRadioDownloadToggled(bool checked)
     QModelIndex index = focusedIndex();
 
     if (index.isValid() && checked) {
-        m_parent->model()->setData(index, FindPDF::Download, PDFListModel::DownloadModeRole);
+        m_parent->model()->setData(index, static_cast<int>(FindPDF::DownloadMode::PDFfile), PDFListModel::DownloadModeRole);
     }
 }
 
@@ -282,7 +299,7 @@ void PDFItemDelegate::slotRadioURLonlyToggled(bool checked)
     QModelIndex index = focusedIndex();
 
     if (index.isValid() && checked) {
-        m_parent->model()->setData(index, FindPDF::URLonly, PDFListModel::DownloadModeRole);
+        m_parent->model()->setData(index, static_cast<int>(FindPDF::DownloadMode::URLonly), PDFListModel::DownloadModeRole);
     }
 }
 
@@ -316,7 +333,7 @@ QVariant PDFListModel::data(const QModelIndex &index, int role) const
             else
                 return QVariant();
         } else if (role == DownloadModeRole)
-            return m_resultList[index.row()].downloadMode;
+            return static_cast<int>(m_resultList[index.row()].downloadMode);
         else if (role == Qt::DecorationRole) {
             /// make an educated guess on the icon, based on URL or path
             QString iconName = FileInfo::mimeTypeForUrl(m_resultList[index.row()].url).iconName();
@@ -343,7 +360,7 @@ bool PDFListModel::setData(const QModelIndex &index, const QVariant &value, int
 
 QVariant PDFListModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    Q_UNUSED(orientation);
+    Q_UNUSED(orientation)
 
     if (section == 0) {
         if (role == Qt::DisplayRole || role == Qt::ToolTipRole) {
@@ -445,13 +462,13 @@ void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
         FindPDF::DownloadMode downloadMode = static_cast<FindPDF::DownloadMode>(model->data(model->index(i, 0), PDFListModel::DownloadModeRole).toInt(&ok));
         if (!ok) {
             qCDebug(LOG_KBIBTEX_GUI) << "Could not interprete download mode";
-            downloadMode = FindPDF::NoDownload;
+            downloadMode = FindPDF::DownloadMode::No;
         }
 
         QUrl url = model->data(model->index(i, 0), PDFListModel::URLRole).toUrl();
         QString tempfileName = model->data(model->index(i, 0), PDFListModel::TempFileNameRole).toString();
 
-        if (downloadMode == FindPDF::URLonly && url.isValid()) {
+        if (downloadMode == FindPDF::DownloadMode::URLonly && url.isValid()) {
             bool alreadyContained = false;
             for (QMap<QString, Value>::ConstIterator it = entry.constBegin(); !alreadyContained && it != entry.constEnd(); ++it)
                 // FIXME this will terribly break if URLs in an entry's URL field are separated with semicolons
@@ -470,7 +487,7 @@ void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
                         }
                     }
             }
-        } else if (downloadMode == FindPDF::Download && !tempfileName.isEmpty()) {
+        } else if (downloadMode == FindPDF::DownloadMode::PDFfile && !tempfileName.isEmpty()) {
             QUrl startUrl = bibtexFile.property(File::Url, QUrl()).toUrl();
             const QString absoluteFilename = QFileDialog::getSaveFileName(this, i18n("Save URL '%1'", url.url(QUrl::PreferLocalFile)), startUrl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).path(), QStringLiteral("application/pdf"));
             if (!absoluteFilename.isEmpty()) {
@@ -486,7 +503,7 @@ void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
                 if (!alreadyContained) {
                     Value value;
                     value.append(QSharedPointer<VerbatimText>(new VerbatimText(visibleFilename)));
-                    const QString fieldNameStem = Preferences::instance().bibliographySystem() == Preferences::BibTeX ? Entry::ftLocalFile : Entry::ftFile;
+                    const QString fieldNameStem = Preferences::instance().bibliographySystem() == Preferences::BibliographySystem::BibTeX ? Entry::ftLocalFile : Entry::ftFile;
                     if (!entry.contains(fieldNameStem))
                         entry.insert(fieldNameStem, value);
                     else
@@ -529,7 +546,3 @@ void FindPDFUI::stopSearch() {
     d->findpdf->abort();
     searchFinished();
 }
-
-void FindPDFUI::abort() {
-    d->findpdf->abort();
-}
