@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,13 +23,11 @@
 #include <QAction>
 #include <QMenu>
 
-#include <KConfigGroup>
 #include <KLocalizedString>
-#include <KSharedConfig>
 
-#include "bibtexfields.h"
-#include "models/filemodel.h"
-#include "sortfilterfilemodel.h"
+#include <BibTeXFields>
+#include <models/FileModel>
+#include "file/sortfilterfilemodel.h"
 #include "logging_gui.h"
 
 class BasicFileView::Private
@@ -53,6 +51,10 @@ public:
     }
 
     void balanceColumns() {
+        if (p->header()->count() != BibTeXFields::instance().count()) {
+            qCWarning(LOG_KBIBTEX_GUI) << "Number of columns in file view does not match number of bibliography fields:" << p->header()->count() << "!=" << BibTeXFields::instance().count();
+            return;
+        }
         int defaultWidthSumVisible = 0;
         int col = 0;
         for (const auto &fd : const_cast<const BibTeXFields &>(BibTeXFields::instance())) {
@@ -72,6 +74,10 @@ public:
     }
 
     void resetColumnProperties() {
+        if (p->header()->count() != BibTeXFields::instance().count()) {
+            qCWarning(LOG_KBIBTEX_GUI) << "Number of columns in file view does not match number of bibliography fields:" << p->header()->count() << "!=" << BibTeXFields::instance().count();
+            return;
+        }
         int col = 0;
         for (BibTeXFields::Iterator it = BibTeXFields::instance().begin(), endIt = BibTeXFields::instance().end(); it != endIt; ++it) {
             auto &fd = *it;
@@ -85,6 +91,10 @@ public:
     }
 
     void loadColumnProperties() {
+        if (p->header()->count() != BibTeXFields::instance().count()) {
+            qCWarning(LOG_KBIBTEX_GUI) << "Number of columns in file view does not match number of bibliography fields:" << p->header()->count() << "!=" << BibTeXFields::instance().count();
+            return;
+        }
         int col = 0;
         for (const auto &fd : const_cast<const BibTeXFields &>(BibTeXFields::instance())) {
             const bool visibility = fd.visible.contains(name) ? fd.visible[name] : fd.defaultVisible;
@@ -95,6 +105,10 @@ public:
     }
 
     void saveColumnProperties() {
+        if (p->header()->count() != BibTeXFields::instance().count()) {
+            qCWarning(LOG_KBIBTEX_GUI) << "Number of columns in file view does not match number of bibliography fields:" << p->header()->count() << "!=" << BibTeXFields::instance().count();
+            return;
+        }
         int col = 0;
         for (BibTeXFields::Iterator it = BibTeXFields::instance().begin(), endIt = BibTeXFields::instance().end(); it != endIt; ++it) {
             auto &fd = *it;
@@ -136,9 +150,6 @@ BasicFileView::~BasicFileView()
 
 void BasicFileView::setModel(QAbstractItemModel *model)
 {
-    if (d->fileModel != nullptr)
-        disconnect(d->fileModel, &FileModel::headerDataChanged, this, &BasicFileView::headerResetToDefaults);
-
     d->sortFilterProxyModel = nullptr;
     d->fileModel = dynamic_cast<FileModel *>(model);
     if (d->fileModel == nullptr) {
@@ -150,9 +161,6 @@ void BasicFileView::setModel(QAbstractItemModel *model)
     }
     if (d->fileModel == nullptr)
         qCWarning(LOG_KBIBTEX_GUI) << "Failed to dynamically cast model to FileModel*";
-    else
-        /// On header data change, e.g. triggered by change of bibliographic system, reset visibile columns
-        connect(d->fileModel, &FileModel::headerDataChanged, this, &BasicFileView::headerResetToDefaults);
 
     QTreeView::setModel(model);
 
@@ -188,7 +196,7 @@ void BasicFileView::keyPressEvent(QKeyEvent *event)
 }
 
 void BasicFileView::resizeEvent(QResizeEvent *event) {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     const int w = qMax(width() - 20, 0);
     header()->setMinimumWidth(w);
     header()->setMaximumWidth(w);
@@ -214,11 +222,6 @@ void BasicFileView::headerActionToggled()
     d->balanceColumns();
 }
 
-void BasicFileView::headerResetToDefaults()
-{
-    d->resetColumnProperties();
-}
-
 void BasicFileView::sort(int t, Qt::SortOrder s)
 {
     SortFilterFileModel *sortedModel = qobject_cast<SortFilterFileModel *>(model());
@@ -264,7 +267,9 @@ void BasicFileView::showHeaderContextMenu(const QPoint &pos)
 
     /// Add action to reset to defaults (regarding column visibility) to header's context menu
     action = new QAction(i18n("Reset to defaults"), &menu);
-    connect(action, &QAction::triggered, this, &BasicFileView::headerResetToDefaults);
+    connect(action, &QAction::triggered, this, [this]() {
+        d->resetColumnProperties();
+    });
     menu.addAction(action);
 
     /// Add separator to header's context menu
