@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,6 +21,7 @@
 #include <QWidget>
 #include <QBoxLayout>
 #include <QLabel>
+#include <QLineEdit>
 #include <QSortFilterProxyModel>
 #include <QStyle>
 #include <QRadioButton>
@@ -38,15 +39,15 @@
 #include <KLocalizedString>
 #include <kparts/part.h>
 #include <KMessageBox>
-#include <KLineEdit>
 
-#include "fileimporterbibtex.h"
-#include "bibtexentries.h"
-#include "radiobuttontreeview.h"
+#include <BibTeXEntries>
+#include <Entry>
+#include <models/FileModel>
+#include <FileImporterBibTeX>
+#include <FindDuplicates>
+#include "widgets/radiobuttontreeview.h"
 #include "fileview.h"
 #include "filedelegate.h"
-#include "models/filemodel.h"
-#include "findduplicates.h"
 #include "logging_gui.h"
 
 /**
@@ -156,7 +157,7 @@ public:
                 else if (fieldName == QStringLiteral("^type"))
                     return i18n("Type");
                 else
-                    return BibTeXEntries::instance().format(fieldName, KBibTeX::cUpperCamelCase);
+                    return BibTeXEntries::instance().format(fieldName, KBibTeX::Casing::UpperCamelCase);
             case RadioButtonTreeView::IsRadioRole:
                 /// this is not to be a radio widget
                 return QVariant::fromValue(false);
@@ -182,7 +183,7 @@ public:
                 if (index.row() < values.count()) {
                     QString text = PlainTextValue::text(values.at(index.row()));
                     if (fieldName == QStringLiteral("^type"))
-                        text = BibTeXEntries::instance().format(text, KBibTeX::cUpperCamelCase);
+                        text = BibTeXEntries::instance().format(text, KBibTeX::Casing::UpperCamelCase);
 
                     /// textual representation of the alternative's value
                     return text;
@@ -259,9 +260,9 @@ public:
                 return true;
             } else if (role == Qt::CheckStateRole && isInt && selectionType(fieldName) == SelectionTypeCheck) {
                 if (checkState == Qt::Checked)
-                    currentClique->setChosenValue(fieldName, values[index.row()], EntryClique::AddValue);
+                    currentClique->setChosenValue(fieldName, values[index.row()], EntryClique::ValueOperation::AddValue);
                 else if (checkState == Qt::Unchecked)
-                    currentClique->setChosenValue(fieldName, values[index.row()], EntryClique::RemoveValue);
+                    currentClique->setChosenValue(fieldName, values[index.row()], EntryClique::ValueOperation::RemoveValue);
                 else
                     return false; ///< tertium non datur
 
@@ -360,8 +361,8 @@ public:
         if (index.parent() != QModelIndex()) {
             /// Only second-level indices in the model can be edited
             /// (those are the actual values).
-            /// Use a plain, border-less KLineEdit.
-            KLineEdit *lineEdit = new KLineEdit(parent);
+            /// Use a plain, border-less QLineEdit.
+            QLineEdit *lineEdit = new QLineEdit(parent);
             lineEdit->setStyleSheet(QStringLiteral("border: none;"));
             return lineEdit;
         }
@@ -369,14 +370,14 @@ public:
     }
 
     void setEditorData(QWidget *editor, const QModelIndex &index) const override {
-        if (KLineEdit *lineEdit = qobject_cast<KLineEdit *>(editor)) {
+        if (QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor)) {
             /// Set line edit's default value to string fetched from model
             lineEdit->setText(index.data(Qt::EditRole).toString());
         }
     }
 
     void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override {
-        if (KLineEdit *lineEdit = qobject_cast<KLineEdit *>(editor)) {
+        if (QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor)) {
             /// Set user-entered text to model (and underlying value)
             model->setData(index, lineEdit->text(), AlternativesItemModel::UserInputRole);
 
