@@ -1,5 +1,5 @@
 /*****************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
  *                                                                           *
  *                                                                           *
  *   This program is free software; you can redistribute it and/or modify    *
@@ -13,27 +13,23 @@
  *   GNU General Public License for more details.                            *
  *                                                                           *
  *   You should have received a copy of the GNU General Public License       *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.    *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.    *
  *****************************************************************************/
 
 #include "italictextitemmodel.h"
 
 #include <QFont>
 
-#include <KDebug>
+#include "logging_gui.h"
 
 class ItalicTextItemModel::Private
 {
-private:
-    // UNUSED ItalicTextItemModel *p;
-
 public:
     QList<QPair<QString, QString> > data;
 
-    Private(ItalicTextItemModel */* UNUSED parent*/)
-    // UNUSED : p(parent)
+    Private(ItalicTextItemModel *parent)
     {
-        /// nothing
+        Q_UNUSED(parent)
     }
 };
 
@@ -72,7 +68,7 @@ QVariant ItalicTextItemModel::data(const QModelIndex &index, int role) const
         /// Show text as passed as first parameter to function addItem
         return d->data[index.row()].first;
     } else if (role == Qt::UserRole) {
-        kWarning() << "Requesting data from Qt::UserRole is deprecated, should not happen";
+        qCWarning(LOG_KBIBTEX_GUI) << "Requesting data from Qt::UserRole is deprecated, should not happen";
     } else if (role == IdentifierRole) {
         /// Return string as passed as second parameter to function addItem
         return d->data[index.row()].second;
