@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,10 +17,15 @@
 
 #include "settingsabstractwidget.h"
 
-#include <KComboBox>
+#include <NotificationHub>
 
 SettingsAbstractWidget::SettingsAbstractWidget(QWidget *parent)
         : QWidget(parent)
 {
     /// nothing
 }
+
+int SettingsAbstractWidget::eventId() const
+{
+    return NotificationHub::EventConfigurationChanged;
+}
