@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,101 +19,84 @@
 
 #include <QFormLayout>
 #include <QPageSize>
-#include <KLineEdit>
+#include <QLineEdit>
+#include <QComboBox>
 
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <KComboBox>
 #include <KLocalizedString>
 
+#include <Preferences>
+#include <FileExporterToolchain>
 #include "guihelper.h"
-#include "fileexportertoolchain.h"
 
 class SettingsFileExporterPDFPSWidget::SettingsFileExporterPDFPSWidgetPrivate
 {
 private:
     SettingsFileExporterPDFPSWidget *p;
 
-    KComboBox *comboBoxPaperSize;
+    QComboBox *comboBoxPaperSize;
 
-    KComboBox *comboBoxBabelLanguage;
-    KComboBox *comboBoxBibliographyStyle;
-
-    KSharedConfigPtr config;
-    const QString configGroupName, configGroupNameGeneral ;
+    QComboBox *comboBoxBabelLanguage;
+    QComboBox *comboBoxBibliographyStyle;
 
 public:
 
     SettingsFileExporterPDFPSWidgetPrivate(SettingsFileExporterPDFPSWidget *parent)
-            : p(parent), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), configGroupName(QStringLiteral("FileExporterPDFPS")), configGroupNameGeneral(QStringLiteral("General")) {
-
+            : p(parent)
+    {
         setupGUI();
     }
 
     void loadState() {
-        KConfigGroup configGroupGeneral(config, configGroupNameGeneral);
-        const QString paperSizeName = configGroupGeneral.readEntry(FileExporter::keyPaperSize, FileExporter::defaultPaperSize);
-        int row = GUIHelper::selectValue(comboBoxPaperSize->model(), paperSizeName, Qt::UserRole);
+        int row = qMax(0, GUIHelper::selectValue(comboBoxPaperSize->model(), static_cast<int>(Preferences::instance().pageSize()), Qt::UserRole));
         comboBoxPaperSize->setCurrentIndex(row);
 
-        KConfigGroup configGroup(config, configGroupName);
-        QString babelLanguage = configGroup.readEntry(FileExporterToolchain::keyBabelLanguage, FileExporterToolchain::defaultBabelLanguage);
-        row = GUIHelper::selectValue(comboBoxBabelLanguage->model(), babelLanguage);
+        const QString babelLanguage = Preferences::instance().laTeXBabelLanguage();
+        row = qMax(0, GUIHelper::selectValue(comboBoxBabelLanguage->model(), babelLanguage));
         comboBoxBabelLanguage->setCurrentIndex(row);
-        QString bibliographyStyle = configGroup.readEntry(FileExporterToolchain::keyBibliographyStyle, FileExporterToolchain::defaultBibliographyStyle);
-        row = GUIHelper::selectValue(comboBoxBibliographyStyle->model(), bibliographyStyle);
+        const QString bibliographyStyle = Preferences::instance().bibTeXBibliographyStyle();
+        row = qMax(0, GUIHelper::selectValue(comboBoxBibliographyStyle->model(), bibliographyStyle));
         comboBoxBibliographyStyle->setCurrentIndex(row);
     }
 
-    void saveState() {
-        KConfigGroup configGroupGeneral(config, configGroupNameGeneral);
-        QString paperSizeName = comboBoxPaperSize->currentData().toString();
-        if (paperSizeName.isEmpty())
-            paperSizeName = FileExporter::defaultPaperSize;
-        configGroupGeneral.writeEntry(FileExporter::keyPaperSize, paperSizeName);
-
-        KConfigGroup configGroup(config, configGroupName);
-        configGroup.writeEntry(FileExporterToolchain::keyBabelLanguage, comboBoxBabelLanguage->lineEdit()->text());
-        configGroup.writeEntry(FileExporterToolchain::keyBibliographyStyle, comboBoxBibliographyStyle->lineEdit()->text());
-        config->sync();
+    bool saveState() {
+        bool settingsGotChanged = false;
+        settingsGotChanged |= Preferences::instance().setPageSize(static_cast<QPageSize::PageSizeId>(comboBoxPaperSize->currentData().toInt()));
+        settingsGotChanged |= Preferences::instance().setLaTeXBabelLanguage(comboBoxBabelLanguage->lineEdit()->text());
+        settingsGotChanged |= Preferences::instance().setBibTeXBibliographyStyle(comboBoxBibliographyStyle->lineEdit()->text());
+        return settingsGotChanged;
     }
 
     void resetToDefaults() {
-        int row = GUIHelper::selectValue(comboBoxPaperSize->model(), FileExporter::defaultPaperSize, Qt::UserRole);
+        int row = qMax(0, GUIHelper::selectValue(comboBoxPaperSize->model(), static_cast<int>(Preferences::defaultPageSize), Qt::UserRole));
         comboBoxPaperSize->setCurrentIndex(row);
-        row = GUIHelper::selectValue(comboBoxBabelLanguage->model(), FileExporterToolchain::defaultBabelLanguage);
+        row = qMax(0, GUIHelper::selectValue(comboBoxBabelLanguage->model(), Preferences::defaultLaTeXBabelLanguage));
         comboBoxBabelLanguage->setCurrentIndex(row);
-        row = GUIHelper::selectValue(comboBoxBibliographyStyle->model(), FileExporterToolchain::defaultBibliographyStyle);
+        row = qMax(0, GUIHelper::selectValue(comboBoxBibliographyStyle->model(), Preferences::defaultBibTeXBibliographyStyle));
         comboBoxBibliographyStyle->setCurrentIndex(row);
     }
 
     void setupGUI() {
         QFormLayout *layout = new QFormLayout(p);
 
-        comboBoxPaperSize = new KComboBox(false, p);
+        comboBoxPaperSize = new QComboBox(p);
         comboBoxPaperSize->setObjectName(QStringLiteral("comboBoxPaperSize"));
         layout->addRow(i18n("Paper Size:"), comboBoxPaperSize);
-        static const QMap<QString, QString> paperSizes = {
-            { QPageSize::name(QPageSize::A4), QStringLiteral("a4") },
-            { QPageSize::name(QPageSize::Letter), QStringLiteral("letter") },
-            { QPageSize::name(QPageSize::Legal), QStringLiteral("legal") },
-        };
-        /// already sorted by key, i.e. the labels
-        for (QMap<QString, QString>::ConstIterator it = paperSizes.begin(); it != paperSizes.end(); ++it) {
-            comboBoxPaperSize->addItem(it.key(), it.value());
-        }
+        for (const auto &dbItem : Preferences::availablePageSizes)
+            comboBoxPaperSize->addItem(QPageSize::name(dbItem.first), dbItem.second);
         connect(comboBoxPaperSize, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsAbstractWidget::changed);
 
-        comboBoxBabelLanguage = new KComboBox(true, p);
+        comboBoxBabelLanguage = new QComboBox(p);
         comboBoxBabelLanguage->setObjectName(QStringLiteral("comboBoxBabelLanguage"));
+        comboBoxBabelLanguage->setEditable(true);
         layout->addRow(i18n("Language for 'babel':"), comboBoxBabelLanguage);
         comboBoxBabelLanguage->addItem(QStringLiteral("english"));
         comboBoxBabelLanguage->addItem(QStringLiteral("ngerman"));
         comboBoxBabelLanguage->addItem(QStringLiteral("swedish"));
         connect(comboBoxBabelLanguage->lineEdit(), &QLineEdit::textChanged, p, &SettingsFileExporterPDFPSWidget::changed);
 
-        comboBoxBibliographyStyle = new KComboBox(true, p);
+        comboBoxBibliographyStyle = new QComboBox(p);
         comboBoxBibliographyStyle->setObjectName(QStringLiteral("comboBoxBibliographyStyle"));
+        comboBoxBibliographyStyle->setEditable(true);
         layout->addRow(i18n("Bibliography style:"), comboBoxBibliographyStyle);
         static const QStringList styles {QString(QStringLiteral("abbrv")), QString(QStringLiteral("alpha")), QString(QStringLiteral("plain")), QString(QStringLiteral("agsm")), QString(QStringLiteral("dcu")), QString(QStringLiteral("jmr")), QString(QStringLiteral("jphysicsB")), QString(QStringLiteral("kluwer")), QString(QStringLiteral("nederlands"))};
         for (const QString &style : styles) {
@@ -149,9 +132,9 @@ void SettingsFileExporterPDFPSWidget::loadState()
     d->loadState();
 }
 
-void SettingsFileExporterPDFPSWidget::saveState()
+bool SettingsFileExporterPDFPSWidget::saveState()
 {
-    d->saveState();
+    return d->saveState();
 }
 
 void SettingsFileExporterPDFPSWidget::resetToDefaults()
