@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,10 +18,10 @@
 #ifndef KBIBTEX_GUI_SETTINGSGLOBALKEYWORDSWIDGET_H
 #define KBIBTEX_GUI_SETTINGSGLOBALKEYWORDSWIDGET_H
 
-#include <kbibtexgui_export.h>
-
 #include "settingsabstractwidget.h"
 
+#include "kbibtexgui_export.h"
+
 class File;
 
 /**
@@ -40,7 +40,7 @@ public:
 
 public slots:
     void loadState() override;
-    void saveState() override;
+    bool saveState() override;
     void resetToDefaults() override;
 
 private slots:
