@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,79 +19,56 @@
 
 #include <QFormLayout>
 #include <QCheckBox>
+#include <QComboBox>
 #include <QBoxLayout>
 
-#include <KComboBox>
 #include <KLocalizedString>
-#include <KSharedConfig>
-#include <KConfigGroup>
 
-#include "preferences.h"
-#include "elementwidgets.h"
-#include "models/filemodel.h"
+#include <Preferences>
+#include "element/elementwidgets.h"
+#include "guihelper.h"
 
 class SettingsUserInterfaceWidget::SettingsUserInterfaceWidgetPrivate
 {
 private:
     SettingsUserInterfaceWidget *p;
 
-    QCheckBox *checkBoxShowComments;
-    QCheckBox *checkBoxShowMacros;
-    KComboBox *comboBoxElementDoubleClickAction;
-
-    KSharedConfigPtr config;
-    static const QString configGroupName;
+    QComboBox *comboBoxElementDoubleClickAction;
 
 public:
     SettingsUserInterfaceWidgetPrivate(SettingsUserInterfaceWidget *parent)
-            : p(parent), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))) {
+            : p(parent) {
         setupGUI();
     }
 
     void loadState() {
-        KConfigGroup configGroup(config, configGroupName);
-        checkBoxShowComments->setChecked(configGroup.readEntry(FileModel::keyShowComments, FileModel::defaultShowComments));
-        checkBoxShowMacros->setChecked(configGroup.readEntry(FileModel::keyShowMacros, FileModel::defaultShowMacros));
-
-        comboBoxElementDoubleClickAction->setCurrentIndex(configGroup.readEntry(Preferences::keyElementDoubleClickAction, static_cast<int>(Preferences::defaultElementDoubleClickAction)));
+        const int row = qMax(0, GUIHelper::selectValue(comboBoxElementDoubleClickAction->model(), static_cast<int>(Preferences::instance().fileViewDoubleClickAction()), Qt::UserRole));
+        comboBoxElementDoubleClickAction->setCurrentIndex(row);
     }
 
-    void saveState() {
-        KConfigGroup configGroup(config, configGroupName);
-        configGroup.writeEntry(FileModel::keyShowComments, checkBoxShowComments->isChecked());
-        configGroup.writeEntry(FileModel::keyShowMacros, checkBoxShowMacros->isChecked());
-        configGroup.writeEntry(Preferences::keyElementDoubleClickAction, comboBoxElementDoubleClickAction->currentIndex());
-        config->sync();
+    bool saveState() {
+        bool settingsGotChanged = false;
+        settingsGotChanged |= Preferences::instance().setFileViewDoubleClickAction(static_cast<Preferences::FileViewDoubleClickAction>(comboBoxElementDoubleClickAction->currentData().toInt()));
+        return settingsGotChanged;
     }
 
     void resetToDefaults() {
-        checkBoxShowComments->setChecked(FileModel::defaultShowComments);
-        checkBoxShowMacros->setChecked(FileModel::defaultShowMacros);
-        comboBoxElementDoubleClickAction->setCurrentIndex(Preferences::defaultElementDoubleClickAction);
+        const int row = qMax(0, GUIHelper::selectValue(comboBoxElementDoubleClickAction->model(), static_cast<int>(Preferences::defaultFileViewDoubleClickAction), Qt::UserRole));
+        comboBoxElementDoubleClickAction->setCurrentIndex(row);
     }
 
     void setupGUI() {
         QFormLayout *layout = new QFormLayout(p);
 
-        checkBoxShowComments = new QCheckBox(p);
-        layout->addRow(i18n("Show Comments:"), checkBoxShowComments);
-        connect(checkBoxShowComments, &QCheckBox::toggled, p, &SettingsUserInterfaceWidget::changed);
-
-        checkBoxShowMacros = new QCheckBox(p);
-        layout->addRow(i18n("Show Macros:"), checkBoxShowMacros);
-        connect(checkBoxShowMacros, &QCheckBox::toggled, p, &SettingsUserInterfaceWidget::changed);
-
-        comboBoxElementDoubleClickAction = new KComboBox(p);
+        comboBoxElementDoubleClickAction = new QComboBox(p);
         comboBoxElementDoubleClickAction->setObjectName(QStringLiteral("comboBoxElementDoubleClickAction"));
-        comboBoxElementDoubleClickAction->addItem(i18n("Open Editor")); ///< ActionOpenEditor = 0
-        comboBoxElementDoubleClickAction->addItem(i18n("View Document")); ///< ActionViewDocument = 1
+        for (QVector<QPair<Preferences::FileViewDoubleClickAction, QString>>::ConstIterator it = Preferences::availableFileViewDoubleClickActions.constBegin(); it != Preferences::availableFileViewDoubleClickActions.constEnd(); ++it)
+            comboBoxElementDoubleClickAction->addItem(it->second, static_cast<int>(it->first));
         layout->addRow(i18n("When double-clicking an element:"), comboBoxElementDoubleClickAction);
         connect(comboBoxElementDoubleClickAction, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsUserInterfaceWidget::changed);
     }
 };
 
-const QString SettingsUserInterfaceWidget::SettingsUserInterfaceWidgetPrivate::configGroupName = QStringLiteral("User Interface");
-
 
 SettingsUserInterfaceWidget::SettingsUserInterfaceWidget(QWidget *parent)
         : SettingsAbstractWidget(parent), d(new SettingsUserInterfaceWidgetPrivate(this))
@@ -119,9 +96,9 @@ void SettingsUserInterfaceWidget::loadState()
     d->loadState();
 }
 
-void SettingsUserInterfaceWidget::saveState()
+bool SettingsUserInterfaceWidget::saveState()
 {
-    d->saveState();
+    return d->saveState();
 }
 
 void SettingsUserInterfaceWidget::resetToDefaults()
