@@ -1,5 +1,5 @@
 /*****************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de>   *
  *                                                                           *
  *                                                                           *
  *   This program is free software; you can redistribute it and/or modify    *
@@ -19,18 +19,15 @@
 #ifndef KBIBTEX_GUI_STARRATING_H
 #define KBIBTEX_GUI_STARRATING_H
 
-#include "kbibtexgui_export.h"
-
 #include <QWidget>
 
-#include <KIconLoader>
+#include <Value>
 
-#include "value.h"
+#include "kbibtexgui_export.h"
 
 class QLabel;
 class QPaintEvent;
 class QMouseEvent;
-
 class QPushButton;
 
 /**
@@ -54,6 +51,7 @@ public:
      * @param parent parent widget
      */
     explicit StarRating(int maxNumberOfStars, QWidget *parent = nullptr);
+    ~StarRating();
 
     /**
      * Get the current rating in percent (i.e >=0.0 and <=100.0).
@@ -83,17 +81,6 @@ public:
      */
     void setReadOnly(bool isReadOnly);
 
-    /**
-     * Paint a horizonal sequence of stars on a painter.
-     *
-     * @param painter painter to draw on
-     * @param defaultState how icons shall be drawn; common values are KIconLoader::DefaultState and KIconLoader::DisabledState
-     * @param numTotalStars maximum/total number of stars
-     * @param percent percent value of "glowing" starts, to be >=0.0 and <= 100.0
-     * @param inside fit and paint stars inside this rectangle on the painter
-     */
-    static void paintStars(QPainter *painter, KIconLoader::States defaultState, int numTotalStars, double percent, const QRect inside);
-
 signals:
     void modified();
 
