@@ -548,7 +548,7 @@ mathCommands[] = {
     {QStringLiteral("theta"), 0x03B8, DirectionBoth},
     {QStringLiteral("iota"), 0x03B9, DirectionBoth},
     {QStringLiteral("kappa"), 0x03BA, DirectionBoth},
-    {QStringLiteral("lamda"), 0x03BB, DirectionBoth}, ///< \lamda does not exist, this is mostly for spelling errors
+    {QStringLiteral("lamda"), 0x03BB, DirectionCommandToUnicode}, ///< \lamda does not exist, this is mostly for spelling errors
     {QStringLiteral("lambda"), 0x03BB, DirectionBoth},
     {QStringLiteral("mu"), 0x03BC, DirectionBoth},
     {QStringLiteral("nu"), 0x03BD, DirectionBoth},
@@ -661,7 +661,12 @@ encoderLaTeXCharacterCommands[] = {
     /** 0x00B2 */
     /** 0x00B3 */
     /** 0x00B4 */
-    {QStringLiteral("textmu"), 0x00B5, DirectionBoth},
+    // Notes about Unicode U+00B5 ('micro sign'):
+    // - Derived from the Greek 'mu' but used as a SI prefix meaning 'one millionth'
+    // - Unicode differs between this symbol and a 'real' Greek 'mu' which has position U+03BC
+    // - There are more lower case 'mu' in Unicode for mathematics (bold, italics, sans-serif, ...)
+    //   at position U+1D6CD and later; those are not supported at all by KBibTeX
+    {QStringLiteral("textmugreek"), 0x00B5, DirectionUnicodeToCommand},
     {QStringLiteral("textparagraph"), 0x00B6, DirectionBoth},
     {QStringLiteral("textpilcrow"), 0x00B6, DirectionBoth},
     {QStringLiteral("textperiodcentered"), 0x00B7, DirectionCommandToUnicode},
@@ -808,6 +813,15 @@ encoderLaTeXCharacterCommands[] = {
     {QStringLiteral("dz"), 0x01F3, DirectionCommandToUnicode},
     {QStringLiteral("HV"), 0x01F6, DirectionCommandToUnicode},
     {QStringLiteral("j"), 0x0237, DirectionBoth},
+    // Notes about Unicode U+03BC ('Greek small letter mu'):
+    // - Unicode differs between this symbol and a 'micro' (SI-prefix) which has position U+00B5
+    // - There are more lower case 'mu' in Unicode for mathematics (bold, italics, sans-serif, ...)
+    //   at position U+1D6CD and later; those are not supported at all by KBibTeX
+    // - LaTeX package 'textcomp' provides command '\textmu' but no other Greek letters
+    // - LaTeX package 'textgreek' provides commands for all Greek letters (e.g. '\textpi') but
+    //   to avoid conflicts with 'textcomp', the command for 'mu' is '\textmugreek'
+    {QStringLiteral("textmugreek"), 0x03BC, DirectionBoth},
+    {QStringLiteral("textmu"), 0x03BC, DirectionCommandToUnicode},
     {QStringLiteral("ldots"), 0x2026, DirectionBoth},
     {QStringLiteral("grqq"), 0x201C, DirectionCommandToUnicode},
     {QStringLiteral("textquotedblleft"), 0x201C, DirectionCommandToUnicode},
@@ -983,7 +997,7 @@ QString EncoderLaTeX::decode(const QString &input) const
                 } else if (lookupTablePos >= 0 && i + skipSpaces < len - 5 && input[i + 3 + skipSpaces] == QLatin1Char('\\') && isIJ(input[i + 4 + skipSpaces]) && input[i + 5 + skipSpaces] == QLatin1Char('}')) {
                     /// This is the case for {\'\i} or alike.
                     for (const DotlessIJCharacter &dotlessIJCharacter : dotlessIJCharacters)
-                        if (dotlessIJCharacter.letter == input[i + 4 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 2]) {
+                        if ((dotlessIJCharacter.direction & DirectionCommandToUnicode) && dotlessIJCharacter.letter == input[i + 4 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 2]) {
                             output.append(QChar(dotlessIJCharacter.unicode));
                             found = true;
                             break;
@@ -1019,7 +1033,7 @@ QString EncoderLaTeX::decode(const QString &input) const
                 } else if (lookupTablePos >= 0 && i + skipSpaces < len - 7 && input[i + 3 + skipSpaces] == QLatin1Char('{') && input[i + 4 + skipSpaces] == QLatin1Char('\\') && isIJ(input[i + 5 + skipSpaces]) && input[i + 6 + skipSpaces] == QLatin1Char('}') && input[i + 7 + skipSpaces] == QLatin1Char('}')) {
                     /// This is the case for {\'{\i}} or alike.
                     for (const DotlessIJCharacter &dotlessIJCharacter : dotlessIJCharacters)
-                        if (dotlessIJCharacter.letter == input[i + 5 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 2]) {
+                        if ((dotlessIJCharacter.direction & DirectionCommandToUnicode) && dotlessIJCharacter.letter == input[i + 5 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 2]) {
                             output.append(QChar(dotlessIJCharacter.unicode));
                             found = true;
                             break;
@@ -1047,7 +1061,7 @@ QString EncoderLaTeX::decode(const QString &input) const
                         /// Check which command it is, then insert corresponding Unicode character
                         found = false;
                         for (const EncoderLaTeXCharacterCommand &encoderLaTeXCharacterCommand : encoderLaTeXCharacterCommands) {
-                            if (encoderLaTeXCharacterCommand.command == alpha) {
+                            if ((encoderLaTeXCharacterCommand.direction & DirectionCommandToUnicode) && encoderLaTeXCharacterCommand.command == alpha) {
                                 output.append(QChar(encoderLaTeXCharacterCommand.unicode));
                                 found = true;
                                 break;
@@ -1059,7 +1073,7 @@ QString EncoderLaTeX::decode(const QString &input) const
                         /// (automatically skipped if command was found above)
                         if (!found)
                             for (const MathCommand &mathCommand : mathCommands) {
-                                if (mathCommand.command == alpha) {
+                                if ((mathCommand.direction & DirectionCommandToUnicode) && mathCommand.command == alpha) {
                                     output.append(QChar(mathCommand.unicode));
                                     found = true;
                                     break;
@@ -1159,7 +1173,7 @@ QString EncoderLaTeX::decode(const QString &input) const
             } else if (lookupTablePos >= 0 && i + skipSpaces < len - 3 && input[i + 2 + skipSpaces] == QLatin1Char('\\') && isIJ(input[i + 3 + skipSpaces])) {
                 /// This is the case for \'\i or alike.
                 for (const DotlessIJCharacter &dotlessIJCharacter : dotlessIJCharacters)
-                    if (dotlessIJCharacter.letter == input[i + 3 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 1]) {
+                    if ((dotlessIJCharacter.direction & DirectionCommandToUnicode) && dotlessIJCharacter.letter == input[i + 3 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 1]) {
                         output.append(QChar(dotlessIJCharacter.unicode));
                         found = true;
                         break;
@@ -1176,7 +1190,7 @@ QString EncoderLaTeX::decode(const QString &input) const
             } else if (lookupTablePos >= 0 && i + skipSpaces < len - 5 && input[i + 2 + skipSpaces] == QLatin1Char('{') && input[i + 3 + skipSpaces] == QLatin1Char('\\') && isIJ(input[i + 4 + skipSpaces]) && input[i + 5 + skipSpaces] == QLatin1Char('}')) {
                 /// This is the case for \'{\i} or alike.
                 for (const DotlessIJCharacter &dotlessIJCharacter : dotlessIJCharacters)
-                    if (dotlessIJCharacter.letter == input[i + 4 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 1]) {
+                    if ((dotlessIJCharacter.direction & DirectionCommandToUnicode) && dotlessIJCharacter.letter == input[i + 4 + skipSpaces] && dotlessIJCharacter.modifier == input[i + 1]) {
                         output.append(QChar(dotlessIJCharacter.unicode));
                         found = true;
                         break;
@@ -1202,7 +1216,7 @@ QString EncoderLaTeX::decode(const QString &input) const
                     /// Check which command it is,
                     /// insert corresponding Unicode character
                     for (const EncoderLaTeXCharacterCommand &encoderLaTeXCharacterCommand : encoderLaTeXCharacterCommands) {
-                        if (encoderLaTeXCharacterCommand.command == alpha) {
+                        if ((encoderLaTeXCharacterCommand.direction & DirectionCommandToUnicode) && encoderLaTeXCharacterCommand.command == alpha) {
                             output.append(QChar(encoderLaTeXCharacterCommand.unicode));
                             found = true;
                             break;
@@ -1214,7 +1228,9 @@ QString EncoderLaTeX::decode(const QString &input) const
                     /// (automatically skipped if command was found above)
                     if (!found)
                         for (const MathCommand &mathCommand : mathCommands) {
-                            if (mathCommand.command == alpha) {
+                            if ((mathCommand.direction & DirectionCommandToUnicode) && mathCommand.command == alpha) {
+                                if (currentMathModeTop() == MathModeNone)
+                                    qDebug() << "Found math mode command" << QString(QStringLiteral("\\%1")).arg(alpha) << "outside of a math expression";
                                 output.append(QChar(mathCommand.unicode));
                                 found = true;
                                 break;
@@ -1274,9 +1290,11 @@ QString EncoderLaTeX::decode(const QString &input) const
                         output.append(QChar(0x2009));
                         // found = true; ///< only necessary if more tests will follow in the future
                         ++i;
+                        found = true;
                     } else {
                         /// Nothing special, copy input char to output
                         output.append(c);
+                        found = true;
                     }
                 }
             } else if (!found) {
@@ -1321,9 +1339,9 @@ QString EncoderLaTeX::decode(const QString &input) const
                 /// text mode and math mode
                 if (c == QLatin1Char('$') && (i == 0 || input[i - 1] != QLatin1Char('\\'))) {
                     if (currentMathModeTop() == MathModeDollar)
-                        currentMathMode.pop();
+                        currentMathMode.pop(); //< the Dollar sign that got just read closes the math mode
                     else
-                        currentMathMode.push(MathModeDollar);
+                        currentMathMode.push(MathModeDollar); //< the Dollar sign that got just read starts a new math mode
                 }
                 if (currentMathModeTop() == MathModeEnsureMath) {
                     if (c == QLatin1Char('{'))
@@ -1400,9 +1418,24 @@ QString EncoderLaTeX::encode(const QString &ninput, const TargetEncoding targetE
             /// If current char is outside ASCII boundaries ...
             bool found = false;
 
+            if (!found && !currentMathMode.empty()) {
+                /// Ok, test for math commands if already in math mode
+                for (const MathCommand &mathCommand : mathCommands)
+                    if ((mathCommand.direction & DirectionUnicodeToCommand) && mathCommand.unicode == c.unicode()) {
+                        output.append(QString(QStringLiteral("\\%1")).arg(mathCommand.command));
+                        const QChar peekAhead = i < len - 1 ? input[i + 1] : QChar();
+                        if (peekAhead != QLatin1Char('\\') && peekAhead != QLatin1Char('}') && peekAhead != QLatin1Char('$')) {
+                            // Between current command and following character a separator is necessary
+                            output.append(QStringLiteral("{}"));
+                        }
+                        found = true;
+                        break;
+                    }
+            }
+
             /// Handle special cases of i without a dot (\i)
             for (const DotlessIJCharacter &dotlessIJCharacter : dotlessIJCharacters)
-                if (c.unicode() == dotlessIJCharacter.unicode && (dotlessIJCharacter.direction & DirectionUnicodeToCommand)) {
+                if ((dotlessIJCharacter.direction & DirectionUnicodeToCommand) && c.unicode() == dotlessIJCharacter.unicode) {
                     output.append(QString(QStringLiteral("{\\%1\\%2}")).arg(dotlessIJCharacter.modifier, dotlessIJCharacter.letter));
                     found = true;
                     break;
@@ -1435,7 +1468,7 @@ QString EncoderLaTeX::encode(const QString &ninput, const TargetEncoding targetE
                 /// Ok, neither a character command. Let's test
                 /// escaped characters with modifiers like \"a
                 for (const EncoderLaTeXEscapedCharacter &encoderLaTeXEscapedCharacter : encoderLaTeXEscapedCharacters)
-                    if (encoderLaTeXEscapedCharacter.unicode == c.unicode() && (encoderLaTeXEscapedCharacter.direction & DirectionUnicodeToCommand)) {
+                    if ((encoderLaTeXEscapedCharacter.direction & DirectionUnicodeToCommand) && encoderLaTeXEscapedCharacter.unicode == c.unicode()) {
                         const QString formatString = isAsciiLetter(encoderLaTeXEscapedCharacter.modifier) ? QStringLiteral("{\\%1 %2}") : QStringLiteral("{\\%1%2}");
                         output.append(formatString.arg(encoderLaTeXEscapedCharacter.modifier).arg(encoderLaTeXEscapedCharacter.letter));
                         found = true;
@@ -1443,19 +1476,11 @@ QString EncoderLaTeX::encode(const QString &ninput, const TargetEncoding targetE
                     }
             }
 
-            if (!found) {
-                /// Ok, test for math commands
+            if (!found && currentMathMode.empty()) {
+                /// Ok, test for math commands, even if outside of a math mode, then enter math mode for this character
                 for (const MathCommand &mathCommand : mathCommands)
-                    if (mathCommand.unicode == c.unicode() && (mathCommand.direction & DirectionUnicodeToCommand)) {
-                        if (!currentMathMode.empty()) {
-                            output.append(QString(QStringLiteral("\\%1")).arg(mathCommand.command));
-                            const QChar peekAhead = i < len - 1 ? input[i + 1] : QChar();
-                            if (peekAhead != QLatin1Char('\\') && peekAhead != QLatin1Char('}') && peekAhead != QLatin1Char('$')) {
-                                /// Between current command and following character a separator is necessary
-                                output.append(QStringLiteral("{}"));
-                            }
-                        } else
-                            output.append(QString(QStringLiteral("\\ensuremath{\\%1}")).arg(mathCommand.command));
+                    if ((mathCommand.direction & DirectionUnicodeToCommand) && mathCommand.unicode == c.unicode()) {
+                        output.append(QString(QStringLiteral("\\ensuremath{\\%1}")).arg(mathCommand.command));
                         found = true;
                         break;
                     }
@@ -1482,20 +1507,50 @@ QString EncoderLaTeX::encode(const QString &ninput, const TargetEncoding targetE
             bool found = false;
             for (const QChar &encoderLaTeXProtectedSymbol : encoderLaTeXProtectedSymbols)
                 if (encoderLaTeXProtectedSymbol == c) {
-                    output.append(QLatin1Char('\\'));
+                    output.append(QLatin1Char('\\')).append(c);
                     found = true;
                     break;
                 }
 
+            if (!found && !currentMathMode.empty()) {
+                /// Ok, test for math commands if already in math mode
+                for (const MathCommand &mathCommand : mathCommands)
+                    if ((mathCommand.direction & DirectionUnicodeToCommand) && mathCommand.unicode == c.unicode()) {
+                        output.append(QString(QStringLiteral("\\%1")).arg(mathCommand.command));
+                        const QChar peekAhead = i < len - 1 ? input[i + 1] : QChar();
+                        if (peekAhead != QLatin1Char('\\') && peekAhead != QLatin1Char('}') && peekAhead != QLatin1Char('$')) {
+                            // Between current command and following character a separator is necessary
+                            output.append(QStringLiteral("{}"));
+                        }
+                        found = true;
+                        break;
+                    }
+            }
+
             if (!found && currentMathMode.empty())
                 for (const QChar &encoderLaTeXProtectedTextOnlySymbol : encoderLaTeXProtectedTextOnlySymbols)
                     if (encoderLaTeXProtectedTextOnlySymbol == c) {
-                        output.append(QLatin1Char('\\'));
+                        output.append(QLatin1Char('\\')).append(c);
+                        found = true;
                         break;
                     }
 
-            /// Dump character to output
-            output.append(c);
+            if (!found && currentMathMode.empty()) {
+                /// Ok, test for math commands, even if outside of a math mode, then enter math mode for this character
+                for (const MathCommand &mathCommand : mathCommands)
+                    if ((mathCommand.direction & DirectionUnicodeToCommand) && mathCommand.unicode == c.unicode()) {
+                        output.append(QString(QStringLiteral("\\ensuremath{\\%1}")).arg(mathCommand.command));
+                        found = true;
+                        break;
+                    }
+            }
+
+            if (!found) {
+                /// Well, either this is not a special character or
+                /// we do not know what to do with it, so just dump it into the output
+                output.append(c);
+                found = true;
+            }
 
             /// Finally, check if input character is a dollar sign
             /// without a preceding backslash, means toggling between
