@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,23 +22,19 @@
 #include <QTextCodec>
 #include <QTextStream>
 #include <QStringList>
+#include <QBuffer>
 
-#ifdef HAVE_KF5
-#include <KSharedConfig>
-#include <KConfigGroup>
-#endif // HAVE_KF5
-
-#include "preferences.h"
-#include "file.h"
-#include "element.h"
-#include "entry.h"
-#include "macro.h"
-#include "preamble.h"
-#include "value.h"
-#include "comment.h"
+#include <BibTeXEntries>
+#include <BibTeXFields>
+#include <Preferences>
+#include <File>
+#include <Element>
+#include <Entry>
+#include <Macro>
+#include <Preamble>
+#include <Value>
+#include <Comment>
 #include "encoderlatex.h"
-#include "bibtexentries.h"
-#include "bibtexfields.h"
 #include "textencoder.h"
 #include "logging_io.h"
 
@@ -60,23 +56,19 @@ public:
     QString listSeparator;
     bool cancelFlag;
     QTextCodec *destinationCodec;
-#ifdef HAVE_KF5
-    KSharedConfigPtr config;
-    const QString configGroupName, configGroupNameGeneral;
-#endif // HAVE_KF5
 
     FileExporterBibTeXPrivate(FileExporterBibTeX *parent)
-            : p(parent), keywordCasing(KBibTeX::cLowerCase), quoteComment(Preferences::qcNone), protectCasing(Qt::PartiallyChecked), cancelFlag(false), destinationCodec(nullptr), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), configGroupName(QStringLiteral("FileExporterBibTeX")), configGroupNameGeneral(QStringLiteral("General")) {
+            : p(parent), keywordCasing(KBibTeX::Casing::LowerCase), quoteComment(Preferences::QuoteComment::None), protectCasing(Qt::PartiallyChecked), cancelFlag(false), destinationCodec(nullptr)
+    {
         /// nothing
     }
 
     void loadState() {
 #ifdef HAVE_KF5
-        KConfigGroup configGroup(config, configGroupName);
-        encoding = configGroup.readEntry(Preferences::keyEncoding, Preferences::defaultEncoding);
-        QString stringDelimiter = configGroup.readEntry(Preferences::keyStringDelimiter, Preferences::defaultStringDelimiter);
+        encoding = Preferences::instance().bibTeXEncoding();
+        QString stringDelimiter = Preferences::instance().bibTeXStringDelimiter();
         if (stringDelimiter.length() != 2)
-            stringDelimiter = Preferences::defaultStringDelimiter;
+            stringDelimiter = Preferences::defaultBibTeXStringDelimiter;
 #else // HAVE_KF5
         encoding = QStringLiteral("LaTeX");
         const QString stringDelimiter = QStringLiteral("{}");
@@ -84,24 +76,17 @@ public:
         stringOpenDelimiter = stringDelimiter[0];
         stringCloseDelimiter = stringDelimiter[1];
 #ifdef HAVE_KF5
-        keywordCasing = static_cast<KBibTeX::Casing>(configGroup.readEntry(Preferences::keyKeywordCasing, static_cast<int>(Preferences::defaultKeywordCasing)));
-        quoteComment = static_cast<Preferences::QuoteComment>(configGroup.readEntry(Preferences::keyQuoteComment, static_cast<int>(Preferences::defaultQuoteComment)));
-        protectCasing = static_cast<Qt::CheckState>(configGroup.readEntry(Preferences::keyProtectCasing, static_cast<int>(Preferences::defaultProtectCasing)));
-        personNameFormatting = configGroup.readEntry(Preferences::keyPersonNameFormatting, QString());
-        listSeparator = configGroup.readEntry(Preferences::keyListSeparator, Preferences::defaultListSeparator);
-
-        if (personNameFormatting.isEmpty()) {
-            /// no person name formatting is specified for BibTeX, fall back to general setting
-            KConfigGroup configGroupGeneral(config, configGroupNameGeneral);
-            personNameFormatting = configGroupGeneral.readEntry(Preferences::keyPersonNameFormatting, Preferences::defaultPersonNameFormatting);
-        }
+        keywordCasing = Preferences::instance().bibTeXKeywordCasing();
+        quoteComment = Preferences::instance().bibTeXQuoteComment();
+        protectCasing = Preferences::instance().bibTeXProtectCasing() ? Qt::Checked : Qt::Unchecked;
+        listSeparator =  Preferences::instance().bibTeXListSeparator();
 #else // HAVE_KF5
-        keywordCasing = KBibTeX::cLowerCase;
+        keywordCasing = KBibTeX::Casing::LowerCase;
         quoteComment = qcNone;
         protectCasing = Qt::PartiallyChecked;
-        personNameFormatting = QStringLiteral("<%l><, %s><, %f>");
         listSeparator = QStringLiteral("; ");
 #endif // HAVE_KF5
+        personNameFormatting = Preferences::instance().personNameFormat();
     }
 
     void loadStateFromFile(const File *bibtexfile) {
@@ -115,11 +100,7 @@ public:
         if (bibtexfile->hasProperty(File::StringDelimiter)) {
             QString stringDelimiter = bibtexfile->property(File::StringDelimiter).toString();
             if (stringDelimiter.length() != 2)
-#ifdef HAVE_KF5
-                stringDelimiter = Preferences::defaultStringDelimiter;
-#else // HAVE_KF5
-                stringDelimiter = QStringLiteral("{}");
-#endif // HAVE_KF5
+                stringDelimiter = Preferences::defaultBibTeXStringDelimiter;
             stringOpenDelimiter = stringDelimiter[0];
             stringCloseDelimiter = stringDelimiter[1];
         }
@@ -140,23 +121,21 @@ public:
     }
 
     bool writeEntry(QIODevice *iodevice, const Entry &entry) {
-        const EncoderLaTeX &laTeXEncoder = EncoderLaTeX::instance();
-
         /// write start of a entry (entry type and id) in plain ASCII
         iodevice->putChar('@');
         iodevice->write(BibTeXEntries::instance().format(entry.type(), keywordCasing).toLatin1().data());
         iodevice->putChar('{');
-        iodevice->write(laTeXEncoder.convertToPlainAscii(entry.id()).toLatin1());
+        iodevice->write(Encoder::instance().convertToPlainAscii(entry.id()).toLatin1());
 
         for (Entry::ConstIterator it = entry.constBegin(); it != entry.constEnd(); ++it) {
             const QString key = it.key();
             Value value = it.value();
             if (value.isEmpty()) continue; ///< ignore empty key-value pairs
 
-            QString text = p->internalValueToBibTeX(value, key, leUTF8);
+            QString text = p->internalValueToBibTeX(value, key, UseLaTeXEncoding::UTF8);
             if (text.isEmpty()) {
                 /// ignore empty key-value pairs
-                qCWarning(LOG_KBIBTEX_IO) << "Value for field " << key << " is empty" << endl;
+                qCWarning(LOG_KBIBTEX_IO) << "Value for field " << key << " is empty";
                 continue;
             }
 
@@ -172,7 +151,7 @@ public:
             iodevice->putChar(',');
             iodevice->putChar('\n');
             iodevice->putChar('\t');
-            iodevice->write(laTeXEncoder.convertToPlainAscii(BibTeXFields::instance().format(key, keywordCasing)).toLatin1());
+            iodevice->write(Encoder::instance().convertToPlainAscii(BibTeXFields::instance().format(key, keywordCasing)).toLatin1());
             iodevice->putChar(' ');
             iodevice->putChar('=');
             iodevice->putChar(' ');
@@ -187,7 +166,7 @@ public:
     }
 
     bool writeMacro(QIODevice *iodevice, const Macro &macro) {
-        QString text = p->internalValueToBibTeX(macro.value(), QString(), leUTF8);
+        QString text = p->internalValueToBibTeX(macro.value(), QString(), UseLaTeXEncoding::UTF8);
         if (protectCasing == Qt::Checked)
             addProtectiveCasing(text);
         else if (protectCasing == Qt::Unchecked)
@@ -211,7 +190,7 @@ public:
     bool writeComment(QIODevice *iodevice, const Comment &comment) {
         QString text = comment.text() ;
 
-        if (comment.useCommand() || quoteComment == Preferences::qcCommand) {
+        if (comment.useCommand() || quoteComment == Preferences::QuoteComment::Command) {
             iodevice->putChar('@');
             iodevice->write(BibTeXEntries::instance().format(QStringLiteral("Comment"), keywordCasing).toLatin1().data());
             iodevice->putChar('{');
@@ -219,8 +198,12 @@ public:
             iodevice->putChar('}');
             iodevice->putChar('\n');
             iodevice->putChar('\n');
-        } else if (quoteComment == Preferences::qcPercentSign) {
+        } else if (quoteComment == Preferences::QuoteComment::PercentSign) {
+#if QT_VERSION >= 0x050e00
+            QStringList commentLines = text.split('\n', Qt::SkipEmptyParts);
+#else // QT_VERSION < 0x050e00
             QStringList commentLines = text.split('\n', QString::SkipEmptyParts);
+#endif // QT_VERSION >= 0x050e00
             for (QStringList::Iterator it = commentLines.begin(); it != commentLines.end(); ++it) {
                 const QByteArray line = TextEncoder::encode(*it, destinationCodec);
                 if (line.length() == 0 || line[0] != QLatin1Char('%')) {
@@ -247,7 +230,7 @@ public:
         iodevice->putChar('{');
         /// Remember: strings from preamble do not get encoded,
         /// may contain raw LaTeX commands and code
-        iodevice->write(TextEncoder::encode(p->internalValueToBibTeX(preamble.value(), QString(), leRaw), destinationCodec));
+        iodevice->write(TextEncoder::encode(p->internalValueToBibTeX(preamble.value(), QString(), UseLaTeXEncoding::Raw), destinationCodec));
         iodevice->putChar('}');
         iodevice->putChar('\n');
         iodevice->putChar('\n');
@@ -389,30 +372,43 @@ bool FileExporterBibTeX::save(QIODevice *iodevice, const File *bibtexfile, QStri
     d->loadState();
     d->loadStateFromFile(bibtexfile);
 
-    if (d->encoding != QStringLiteral("latex")) {
-        Comment encodingComment(QStringLiteral("x-kbibtex-encoding=") + d->encoding, true);
-        result &= d->writeComment(iodevice, encodingComment);
-    }
+    QBuffer outputBuffer;
+    outputBuffer.open(QBuffer::WriteOnly);
 
     /// Memorize which entries are used in a crossref field
-    QStringList crossRefIdList;
+    QHash<QString, QStringList> crossRefMap;
     for (File::ConstIterator it = bibtexfile->constBegin(); it != bibtexfile->constEnd() && result && !d->cancelFlag; ++it) {
         QSharedPointer<const Entry> entry = (*it).dynamicCast<const Entry>();
         if (!entry.isNull()) {
             const QString crossRef = PlainTextValue::text(entry->value(Entry::ftCrossRef));
-            if (!crossRef.isEmpty())
-                crossRefIdList << crossRef;
+            if (!crossRef.isEmpty()) {
+                QStringList crossRefList = crossRefMap.value(crossRef, QStringList());
+                crossRefList.append(entry->id());
+                crossRefMap.insert(crossRef, crossRefList);
+            }
         }
     }
 
     bool allPreamblesAndMacrosProcessed = false;
+    QSet<QString> processedEntryIds;
     for (File::ConstIterator it = bibtexfile->constBegin(); it != bibtexfile->constEnd() && result && !d->cancelFlag; ++it) {
         QSharedPointer<const Element> element = (*it);
         QSharedPointer<const Entry> entry = element.dynamicCast<const Entry>();
 
         if (!entry.isNull()) {
+            processedEntryIds.insert(entry->id());
+
             /// Postpone entries that are crossref'ed
-            if (crossRefIdList.contains(entry->id())) continue;
+            const QStringList crossRefList = crossRefMap.value(entry->id(), QStringList());
+            if (!crossRefList.isEmpty()) {
+                bool allProcessed = true;
+                for (const QString &origin : crossRefList)
+                    allProcessed &= processedEntryIds.contains(origin);
+                if (allProcessed)
+                    crossRefMap.remove(entry->id());
+                else
+                    continue;
+            }
 
             if (!allPreamblesAndMacrosProcessed) {
                 /// Guarantee that all macros and the preamble are written
@@ -420,12 +416,12 @@ bool FileExporterBibTeX::save(QIODevice *iodevice, const File *bibtexfile, QStri
                 for (File::ConstIterator msit = it + 1; msit != bibtexfile->constEnd() && result && !d->cancelFlag; ++msit) {
                     QSharedPointer<const Preamble> preamble = (*msit).dynamicCast<const Preamble>();
                     if (!preamble.isNull()) {
-                        result &= d->writePreamble(iodevice, *preamble);
+                        result &= d->writePreamble(&outputBuffer, *preamble);
                         emit progress(++currentPos, totalElements);
                     } else {
                         QSharedPointer<const Macro> macro = (*msit).dynamicCast<const Macro>();
                         if (!macro.isNull()) {
-                            result &= d->writeMacro(iodevice, *macro);
+                            result &= d->writeMacro(&outputBuffer, *macro);
                             emit progress(++currentPos, totalElements);
                         }
                     }
@@ -433,22 +429,22 @@ bool FileExporterBibTeX::save(QIODevice *iodevice, const File *bibtexfile, QStri
                 allPreamblesAndMacrosProcessed = true;
             }
 
-            result &= d->writeEntry(iodevice, *entry);
+            result &= d->writeEntry(&outputBuffer, *entry);
             emit progress(++currentPos, totalElements);
         } else {
             QSharedPointer<const Comment> comment = element.dynamicCast<const Comment>();
             if (!comment.isNull() && !comment->text().startsWith(QStringLiteral("x-kbibtex-"))) {
-                result &= d->writeComment(iodevice, *comment);
+                result &= d->writeComment(&outputBuffer, *comment);
                 emit progress(++currentPos, totalElements);
             } else if (!allPreamblesAndMacrosProcessed) {
                 QSharedPointer<const Preamble> preamble = element.dynamicCast<const Preamble>();
                 if (!preamble.isNull()) {
-                    result &= d->writePreamble(iodevice, *preamble);
+                    result &= d->writePreamble(&outputBuffer, *preamble);
                     emit progress(++currentPos, totalElements);
                 } else {
                     QSharedPointer<const Macro> macro = element.dynamicCast<const Macro>();
                     if (!macro.isNull()) {
-                        result &= d->writeMacro(iodevice, *macro);
+                        result &= d->writeMacro(&outputBuffer, *macro);
                         emit progress(++currentPos, totalElements);
                     }
                 }
@@ -457,15 +453,36 @@ bool FileExporterBibTeX::save(QIODevice *iodevice, const File *bibtexfile, QStri
     }
 
     /// Crossref'ed entries are written last
-    for (File::ConstIterator it = bibtexfile->constBegin(); it != bibtexfile->constEnd() && result && !d->cancelFlag; ++it) {
-        QSharedPointer<const Entry> entry = (*it).dynamicCast<const Entry>();
-        if (entry.isNull()) continue;
-        if (!crossRefIdList.contains(entry->id())) continue;
+    if (!crossRefMap.isEmpty())
+        for (File::ConstIterator it = bibtexfile->constBegin(); it != bibtexfile->constEnd() && result && !d->cancelFlag; ++it) {
+            QSharedPointer<const Entry> entry = (*it).dynamicCast<const Entry>();
+            if (entry.isNull()) continue;
+            if (!crossRefMap.contains(entry->id())) continue;
 
-        result &= d->writeEntry(iodevice, *entry);
-        emit progress(++currentPos, totalElements);
+            result &= d->writeEntry(&outputBuffer, *entry);
+            emit progress(++currentPos, totalElements);
+        }
+
+    outputBuffer.close(); ///< close writing operation
+
+    outputBuffer.open(QBuffer::ReadOnly);
+    const QByteArray outputData = outputBuffer.readAll();
+    outputBuffer.close();
+    bool hasNonAsciiCharacters = false;
+    for (const unsigned char c : outputData)
+        if ((c & 128) > 0) {
+            hasNonAsciiCharacters = true;
+            break;
+        }
+
+    if (hasNonAsciiCharacters) {
+        const QString encoding = d->encoding.toLower() == QStringLiteral("latex") ? QStringLiteral("utf-8") : d->encoding;
+        Comment encodingComment(QStringLiteral("x-kbibtex-encoding=") + encoding, true);
+        result &= d->writeComment(iodevice, encodingComment);
     }
 
+    iodevice->write(outputData);
+
     iodevice->close();
     return result && !d->cancelFlag;
 }
@@ -527,8 +544,8 @@ QString FileExporterBibTeX::valueToBibTeX(const Value &value, const QString &key
 
 QString FileExporterBibTeX::applyEncoder(const QString &input, UseLaTeXEncoding useLaTeXEncoding) const {
     switch (useLaTeXEncoding) {
-    case leLaTeX: return EncoderLaTeX::instance().encode(input, Encoder::TargetEncodingASCII);
-    case leUTF8: return EncoderLaTeX::instance().encode(input, Encoder::TargetEncodingUTF8);
+    case UseLaTeXEncoding::LaTeX: return EncoderLaTeX::instance().encode(input, Encoder::TargetEncoding::ASCII);
+    case UseLaTeXEncoding::UTF8: return EncoderLaTeX::instance().encode(input, Encoder::TargetEncoding::UTF8);
     default: return input;
     }
 }
