@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -63,7 +63,7 @@ bool FileExporterBibUtils::save(QIODevice *iodevice, const File *bibtexfile, QSt
     QBuffer buffer;
     bool result = d->bibtexExporter->save(&buffer, bibtexfile, errorLog);
     if (result)
-        result = convert(buffer, BibUtils::BibTeX, *iodevice, format());
+        result = convert(buffer, BibUtils::Format::BibTeX, *iodevice, format());
 
     iodevice->close();
     return result;
@@ -77,7 +77,7 @@ bool FileExporterBibUtils::save(QIODevice *iodevice, const QSharedPointer<const
     QBuffer buffer;
     bool result = d->bibtexExporter->save(&buffer, element, bibtexfile, errorLog);
     if (result)
-        result = convert(buffer, BibUtils::BibTeX, *iodevice, format());
+        result = convert(buffer, BibUtils::Format::BibTeX, *iodevice, format());
 
     iodevice->close();
     return result;
