@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -14,10 +14,15 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
-#ifndef BIBTEXFILEEXPORTERPS_H
-#define BIBTEXFILEEXPORTERPS_H
 
-#include "fileexportertoolchain.h"
+#ifndef KBIBTEX_IO_FILEEXPORTERPS_H
+#define KBIBTEX_IO_FILEEXPORTERPS_H
+
+#include <FileExporterToolchain>
+
+#ifdef HAVE_KF5
+#include "kbibtexio_export.h"
+#endif // HAVE_KF5
 
 class QStringList;
 
@@ -32,22 +37,16 @@ public:
     explicit FileExporterPS(QObject *parent);
     ~FileExporterPS() override;
 
-    void reloadConfig() override;
-
     bool save(QIODevice *iodevice, const File *bibtexfile, QStringList *errorLog = nullptr) override;
     bool save(QIODevice *iodevice, const QSharedPointer<const Element> element, const File *bibtexfile, QStringList *errorLog = nullptr) override;
 
 private:
     QString m_fileBasename;
     QString m_fileStem;
-    QString m_babelLanguage;
-    QString m_paperSize;
-    QString m_bibliographyStyle;
 
     bool generatePS(QIODevice *iodevice, QStringList *errorLog);
     bool writeLatexFile(const QString &filename);
     bool beautifyPostscriptFile(const QString &filename, const QString &title);
 };
 
-
-#endif
+#endif // KBIBTEX_IO_FILEEXPORTERPS_H
