@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,12 +22,10 @@
 #include <QTextStream>
 #include <QDir>
 
-#include <KSharedConfig>
-#include <KConfigGroup>
-
-#include "element.h"
+#include <KBibTeX>
+#include <Preferences>
+#include <Element>
 #include "fileexporterbibtex.h"
-#include "kbibtex.h"
 #include "logging_io.h"
 
 FileExporterRTF::FileExporterRTF(QObject *parent)
@@ -35,8 +33,6 @@ FileExporterRTF::FileExporterRTF(QObject *parent)
 {
     m_fileBasename = QStringLiteral("bibtex-to-rtf");
     m_fileStem = tempDir.path() + QDir::separator() + m_fileBasename;
-
-    reloadConfig();
 }
 
 FileExporterRTF::~FileExporterRTF()
@@ -44,17 +40,6 @@ FileExporterRTF::~FileExporterRTF()
     /// nothing
 }
 
-void FileExporterRTF::reloadConfig()
-{
-    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
-    KConfigGroup configGroup(config, QStringLiteral("FileExporterPDFPS"));
-    m_babelLanguage = configGroup.readEntry(keyBabelLanguage, defaultBabelLanguage);
-    m_bibliographyStyle = configGroup.readEntry(keyBibliographyStyle, defaultBibliographyStyle);
-
-    KConfigGroup configGroupGeneral(config, QStringLiteral("General"));
-    m_paperSize = configGroupGeneral.readEntry(keyPaperSize, defaultPaperSize);
-}
-
 bool FileExporterRTF::save(QIODevice *iodevice, const File *bibtexfile, QStringList *errorLog)
 {
     if (!iodevice->isWritable() && !iodevice->open(QIODevice::WriteOnly)) {
@@ -105,7 +90,7 @@ bool FileExporterRTF::save(QIODevice *iodevice, const QSharedPointer<const Eleme
 
 bool FileExporterRTF::generateRTF(QIODevice *iodevice, QStringList *errorLog)
 {
-    QStringList cmdLines {QStringLiteral("latex -halt-on-error bibtex-to-rtf.tex"), QStringLiteral("bibtex bibtex-to-rtf"), QStringLiteral("latex -halt-on-error bibtex-to-rtf.tex"), QString(QStringLiteral("latex2rtf -i %1 bibtex-to-rtf.tex")).arg(m_babelLanguage)};
+    QStringList cmdLines {QStringLiteral("latex -halt-on-error bibtex-to-rtf.tex"), QStringLiteral("bibtex bibtex-to-rtf"), QStringLiteral("latex -halt-on-error bibtex-to-rtf.tex"), QString(QStringLiteral("latex2rtf -i %1 bibtex-to-rtf.tex")).arg(Preferences::instance().laTeXBabelLanguage())};
 
     return writeLatexFile(m_fileStem + KBibTeX::extensionTeX) && runProcesses(cmdLines, errorLog) && writeFileToIODevice(m_fileStem + KBibTeX::extensionRTF, iodevice, errorLog);
 }
@@ -116,24 +101,59 @@ bool FileExporterRTF::writeLatexFile(const QString &filename)
     if (latexFile.open(QIODevice::WriteOnly)) {
         QTextStream ts(&latexFile);
         ts.setCodec("UTF-8");
+#if QT_VERSION >= 0x050e00
+        ts << "\\documentclass{article}" << Qt::endl;
+        ts << "\\usepackage[T1]{fontenc}" << Qt::endl;
+        ts << "\\usepackage[utf8]{inputenc}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
         ts << "\\documentclass{article}" << endl;
         ts << "\\usepackage[T1]{fontenc}" << endl;
         ts << "\\usepackage[utf8]{inputenc}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("babel.sty")))
-            ts << "\\usepackage[" << m_babelLanguage << "]{babel}" << endl;
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[" << Preferences::instance().laTeXBabelLanguage() << "]{babel}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+            ts << "\\usepackage[" << Preferences::instance().laTeXBabelLanguage() << "]{babel}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("url.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage{url}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage{url}" << endl;
-        if (m_bibliographyStyle.startsWith(QStringLiteral("apacite")) && kpsewhich(QStringLiteral("apacite.sty")))
+#endif // QT_VERSION >= 0x050e00
+        const QString bibliographyStyle = Preferences::instance().bibTeXBibliographyStyle();
+        if (bibliographyStyle.startsWith(QStringLiteral("apacite")) && kpsewhich(QStringLiteral("apacite.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[bibnewpage]{apacite}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage[bibnewpage]{apacite}" << endl;
-        if (m_bibliographyStyle == QStringLiteral("dcu") && kpsewhich(QStringLiteral("harvard.sty")) && kpsewhich(QStringLiteral("html.sty")))
+#endif // QT_VERSION >= 0x050e00
+        if (bibliographyStyle == QStringLiteral("dcu") && kpsewhich(QStringLiteral("harvard.sty")) && kpsewhich(QStringLiteral("html.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage{html}" << Qt::endl << "\\usepackage[dcucite]{harvard}" << Qt::endl << "\\renewcommand{\\harvardurl}{URL: \\url}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage{html}" << endl << "\\usepackage[dcucite]{harvard}" << endl << "\\renewcommand{\\harvardurl}{URL: \\url}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("geometry.sty")))
-            ts << "\\usepackage[paper=" << m_paperSize << (m_paperSize.length() <= 2 ? "paper" : "") << "]{geometry}" << endl;
-        ts << "\\bibliographystyle{" << m_bibliographyStyle << "}" << endl;
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[paper=" << pageSizeToLaTeXName(Preferences::instance().pageSize()) << "]{geometry}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+            ts << "\\usepackage[paper=" << pageSizeToLaTeXName(Preferences::instance().pageSize()) << "]{geometry}" << endl;
+#endif // QT_VERSION >= 0x050e00
+#if QT_VERSION >= 0x050e00
+        ts << "\\bibliographystyle{" << bibliographyStyle << "}" << Qt::endl;
+        ts << "\\begin{document}" << Qt::endl;
+        ts << "\\nocite{*}" << Qt::endl;
+        ts << "\\bibliography{bibtex-to-rtf}" << Qt::endl;
+        ts << "\\end{document}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+        ts << "\\bibliographystyle{" << bibliographyStyle << "}" << endl;
         ts << "\\begin{document}" << endl;
         ts << "\\nocite{*}" << endl;
         ts << "\\bibliography{bibtex-to-rtf}" << endl;
         ts << "\\end{document}" << endl;
+#endif // QT_VERSION >= 0x050e00
         latexFile.close();
         return true;
     }
