@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,6 +19,7 @@
 
 #include <QBuffer>
 
+#include <File>
 #include "fileimporterbibtex.h"
 #include "logging_io.h"
 
@@ -58,10 +59,14 @@ File *FileImporterBibUtils::load(QIODevice *iodevice)
     if (!iodevice->isReadable() && !iodevice->open(QIODevice::ReadOnly)) {
         qCWarning(LOG_KBIBTEX_IO) << "Input device not readable";
         return nullptr;
+    } else if (iodevice->atEnd() || iodevice->size() <= 0) {
+        qCWarning(LOG_KBIBTEX_IO) << "Input device at end or does not contain any data";
+        emit message(MessageSeverity::Warning, QStringLiteral("Input device at end or does not contain any data"));
+        return new File();
     }
 
     QBuffer buffer;
-    const bool result = convert(*iodevice, format(), buffer, BibUtils::BibTeX);
+    const bool result = convert(*iodevice, format(), buffer, BibUtils::Format::BibTeX);
     iodevice->close();
 
     if (result)
