@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,14 +20,15 @@
 #include <poppler-qt5.h>
 
 #include <QFileInfo>
+#include <QMimeDatabase>
 #include <QDir>
 #include <QTextStream>
 #include <QStandardPaths>
 #include <QRegularExpression>
 #include <QtConcurrentRun>
 
-#include "kbibtex.h"
-#include "entry.h"
+#include <KBibTeX>
+#include <Entry>
 #include "logging_io.h"
 
 FileInfo::FileInfo()
@@ -43,7 +44,7 @@ const QString FileInfo::mimetypePDF = QStringLiteral("application/pdf");
 
 QMimeType FileInfo::mimeTypeForUrl(const QUrl &url)
 {
-    if (!url.isValid() || url.isEmpty()) {
+    if (!url.isValid()) {
         qCWarning(LOG_KBIBTEX_IO) << "Cannot determine mime type for empty or invalid QUrl";
         return QMimeType(); ///< invalid input gives invalid mime type
     }
@@ -129,12 +130,16 @@ void FileInfo::urlsInText(const QString &text, const TestExistence testExistence
             internalText = internalText.left(pos) + internalText.mid(pos + doiMatch.length());
     }
 
+#if QT_VERSION >= 0x050e00
+    const QStringList fileList = internalText.split(KBibTeX::fileListSeparatorRegExp, Qt::SkipEmptyParts);
+#else // QT_VERSION < 0x050e00
     const QStringList fileList = internalText.split(KBibTeX::fileListSeparatorRegExp, QString::SkipEmptyParts);
+#endif // QT_VERSION >= 0x050e00
     for (const QString &text : fileList) {
         internalText = text;
 
         /// If testing for the actual existence of a filename found in the text ...
-        if (testExistence == TestExistenceYes) {
+        if (testExistence == TestExistence::Yes) {
             /// If a base directory (e.g. the location of the parent .bib file) is given
             /// and the potential filename fragment is NOT an absolute path, ...
             if (internalText.startsWith(QStringLiteral("~") + QDir::separator())) {
@@ -181,7 +186,7 @@ void FileInfo::urlsInText(const QString &text, const TestExistence testExistence
             pos = urlRegExpMatch.capturedStart(0);
             const QString match = urlRegExpMatch.captured(0);
             QUrl url(match);
-            if (url.isValid() && (testExistence == TestExistenceNo || !url.isLocalFile() || QFileInfo::exists(url.toLocalFile())) && !result.contains(url))
+            if (url.isValid() && (testExistence == TestExistence::No || !url.isLocalFile() || QFileInfo::exists(url.toLocalFile())) && !result.contains(url))
                 result << url;
             /// remove match from internal text to avoid duplicates
             internalText = internalText.left(pos) + internalText.mid(pos + match.length());
@@ -208,8 +213,9 @@ void FileInfo::urlsInText(const QString &text, const TestExistence testExistence
         while ((fileRegExpMatch = KBibTeX::fileRegExp.match(internalText, pos)).hasMatch()) {
             pos = fileRegExpMatch.capturedStart(0);
             const QString match = fileRegExpMatch.captured(0);
-            QUrl url(match);
-            if (url.isValid() && (testExistence == TestExistenceNo || !url.isLocalFile() || QFileInfo::exists(url.toLocalFile())) && !result.contains(url))
+            const QFileInfo fi(match);
+            const QUrl url = QUrl::fromLocalFile(!match.startsWith(QStringLiteral("/")) && !match.startsWith(QStringLiteral("http")) && fi.isRelative() && !baseDirectory.isEmpty() ? baseDirectory + QStringLiteral("/") + match : match);
+            if (url.isValid() && (testExistence == TestExistence::No || QFileInfo::exists(url.toLocalFile())) && !result.contains(url))
                 result << url;
             /// remove match from internal text to avoid duplicates
             internalText = internalText.left(pos) + internalText.mid(pos + match.length());
@@ -285,20 +291,23 @@ QSet<QUrl> FileInfo::entryUrls(const QSharedPointer<const Entry> &entry, const Q
             }
         }
 
-        /// check if in the same directory as the BibTeX file there is a subdirectory
+        /// Check if in the same directory as the BibTeX file there is a subdirectory
         /// similar to the BibTeX file's name and which contains a PDF file exists
         /// which filename is based on the entry's id
-        static const QRegularExpression filenameExtension(QStringLiteral("\\.[^.]{2,5}$"));
-        const QString basename = bibTeXUrl.fileName().remove(filenameExtension);
-        QString directory = baseDirectory + QDir::separator() + basename;
-        for (const QString &extension : documentFileExtensions) {
-            const QFileInfo fi(directory + QDir::separator() + entry->id() + extension);
-            if (fi.exists()) {
-                const QUrl url = QUrl::fromLocalFile(fi.canonicalFilePath());
-                if (!result.contains(url))
-                    result << url;
+        const QFileInfo filenameInfo(bibTeXUrl.fileName());
+        const QString ending = filenameInfo.completeSuffix();
+        QString directory = baseDirectory + QDir::separator() + bibTeXUrl.fileName();
+        directory.chop(ending.length() + 1);
+        const QFileInfo fi(directory);
+        if (fi.isDir())
+            for (const QString &extension : documentFileExtensions) {
+                const QFileInfo fi(directory + QDir::separator() + entry->id() + extension);
+                if (fi.exists()) {
+                    const QUrl url = QUrl::fromLocalFile(fi.canonicalFilePath());
+                    if (!result.contains(url))
+                        result << url;
+                }
             }
-        }
     }
 
     return result;
