@@ -28,13 +28,13 @@
 
 #include <poppler-qt5.h>
 
-#include "kbibtex.h"
+#include <KBibTeX>
+#include <Value>
+#include <FileInfo>
 #include "internalnetworkaccessmanager.h"
-#include "value.h"
-#include "fileinfo.h"
 #include "logging_networking.h"
 
-int maxDepth = 5;
+static const int maxDepth = 5;
 static const char *depthProperty = "depth";
 static const char *termProperty = "term";
 static const char *originProperty = "origin";
@@ -204,7 +204,7 @@ public:
             resultItem.tempFilename = new QTemporaryFile(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QDir::separator() + QStringLiteral("kbibtex_findpdf_XXXXXX.pdf"));
             resultItem.tempFilename->setAutoRemove(true);
             if (resultItem.tempFilename->open()) {
-                const int lenDataWritten = resultItem.tempFilename->write(data);
+                const int lenDataWritten = static_cast<int>(resultItem.tempFilename->write(data));
                 resultItem.tempFilename->close();
                 if (lenDataWritten != data.length()) {
                     /// Failed to write to temporary file
@@ -228,7 +228,7 @@ public:
                 delete page;
             }
             resultItem.textPreview.remove(QStringLiteral("Microsoft Word - ")); ///< Some word processors need to put their name everywhere ...
-            resultItem.downloadMode = NoDownload;
+            resultItem.downloadMode = DownloadMode::No;
             resultItem.relevance = origin == Entry::ftDOI ? 1.0 : (origin == QStringLiteral("eprint") ? 0.75 : 0.5);
             result << resultItem;
             progress = true;
@@ -281,7 +281,11 @@ bool FindPDF::search(const Entry &entry)
     /// Generate a string which contains the title's beginning
     QString searchWords;
     if (entry.contains(Entry::ftTitle)) {
+#if QT_VERSION >= 0x050e00
+        const QStringList titleChunks = PlainTextValue::text(entry.value(Entry::ftTitle)).split(QStringLiteral(" "), Qt::SkipEmptyParts);
+#else // QT_VERSION < 0x050e00
         const QStringList titleChunks = PlainTextValue::text(entry.value(Entry::ftTitle)).split(QStringLiteral(" "), QString::SkipEmptyParts);
+#endif // QT_VERSION >= 0x050e00
         if (!titleChunks.isEmpty()) {
             searchWords = titleChunks[0];
             for (int i = 1; i < titleChunks.count() && searchWords.length() < 64; ++i)
@@ -392,10 +396,10 @@ void FindPDF::downloadFinished()
         const QByteArray data = reply->readAll();
 
         QUrl redirUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
-        redirUrl = redirUrl.isEmpty() ? QUrl() : reply->url().resolved(redirUrl);
+        redirUrl = redirUrl.isValid() ? reply->url().resolved(redirUrl) : QUrl();
         qCDebug(LOG_KBIBTEX_NETWORKING) << "finished Downloading " << reply->url().toDisplayString() << "   depth=" << depth  << "  d->aliveCounter=" << d->aliveCounter << "  data.size=" << data.size() << "  redirUrl=" << redirUrl.toDisplayString() << "   origin=" << origin;
 
-        if (!redirUrl.isEmpty()) {
+        if (redirUrl.isValid()) {
             redirUrl = d->ieeeDocumentUrlToDownloadUrl(redirUrl);
             d->queueUrl(redirUrl, term, origin, depth - 1);
         } else if (data.contains(htmlHead1) || data.contains(htmlHead2) || data.contains(htmlHead3)) {
