@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,6 +21,8 @@
 #ifdef HAVE_QTWIDGETS
 #include <QLayout>
 #include <QSpinBox>
+#include <QComboBox>
+#include <QLineEdit>
 #include <QLabel>
 #include <QIcon>
 #endif // HAVE_QTWIDGETS
@@ -29,21 +31,20 @@
 #ifdef HAVE_KF5
 #include <KLocalizedString>
 #include <KConfigGroup>
-#include <KComboBox>
 #include <KMessageBox>
-#include <KLineEdit>
 #else // HAVE_KF5
 #define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
-#include "fileimporterbibtex.h"
-#include "file.h"
-#include "entry.h"
+#include <FileImporterBibTeX>
+#include <File>
+#include <Entry>
 #include "internalnetworkaccessmanager.h"
+#include "onlinesearchabstract_p.h"
 #include "logging_networking.h"
 
 #ifdef HAVE_QTWIDGETS
-class OnlineSearchBibsonomy::OnlineSearchQueryFormBibsonomy : public OnlineSearchQueryFormAbstract
+class OnlineSearchBibsonomy::Form : public OnlineSearchAbstract::Form
 {
     Q_OBJECT
 
@@ -51,24 +52,25 @@ private:
     QString configGroupName;
 
     void loadState() {
-        KConfigGroup configGroup(config, configGroupName);
+        KConfigGroup configGroup(d->config, configGroupName);
         comboBoxSearchWhere->setCurrentIndex(configGroup.readEntry(QStringLiteral("searchWhere"), 0));
         lineEditSearchTerm->setText(configGroup.readEntry(QStringLiteral("searchTerm"), QString()));
         numResultsField->setValue(configGroup.readEntry(QStringLiteral("numResults"), 10));
     }
 
 public:
-    KComboBox *comboBoxSearchWhere;
-    KLineEdit *lineEditSearchTerm;
+    QComboBox *comboBoxSearchWhere;
+    QLineEdit *lineEditSearchTerm;
     QSpinBox *numResultsField;
 
-    OnlineSearchQueryFormBibsonomy(QWidget *widget)
-            : OnlineSearchQueryFormAbstract(widget), configGroupName(QStringLiteral("Search Engine Bibsonomy")) {
+    Form(QWidget *widget)
+            : OnlineSearchAbstract::Form(widget), configGroupName(QStringLiteral("Search Engine Bibsonomy")) {
         QGridLayout *layout = new QGridLayout(this);
         layout->setMargin(0);
 
-        comboBoxSearchWhere = new KComboBox(false, this);
+        comboBoxSearchWhere = new QComboBox(this);
         layout->addWidget(comboBoxSearchWhere, 0, 0, 1, 1);
+        comboBoxSearchWhere->setEditable(true);
         comboBoxSearchWhere->addItem(i18n("Tag"), "tag");
         comboBoxSearchWhere->addItem(i18n("User"), "user");
         comboBoxSearchWhere->addItem(i18n("Group"), "group");
@@ -78,10 +80,10 @@ public:
         comboBoxSearchWhere->addItem(i18n("Everywhere"), "search");
         comboBoxSearchWhere->setCurrentIndex(comboBoxSearchWhere->count() - 1);
 
-        lineEditSearchTerm = new KLineEdit(this);
+        lineEditSearchTerm = new QLineEdit(this);
         layout->addWidget(lineEditSearchTerm, 0, 1, 1, 1);
         lineEditSearchTerm->setClearButtonEnabled(true);
-        connect(lineEditSearchTerm, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormBibsonomy::returnPressed);
+        connect(lineEditSearchTerm, &QLineEdit::returnPressed, this, &OnlineSearchBibsonomy::Form::returnPressed);
 
         QLabel *label = new QLabel(i18n("Number of Results:"), this);
         layout->addWidget(label, 1, 0, 1, 1);
@@ -104,15 +106,15 @@ public:
 
     void copyFromEntry(const Entry &entry) override {
         comboBoxSearchWhere->setCurrentIndex(comboBoxSearchWhere->count() - 1);
-        lineEditSearchTerm->setText(authorLastNames(entry).join(QStringLiteral(" ")) + QLatin1Char(' ') + PlainTextValue::text(entry[Entry::ftTitle]));
+        lineEditSearchTerm->setText(d->authorLastNames(entry).join(QStringLiteral(" ")) + QLatin1Char(' ') + PlainTextValue::text(entry[Entry::ftTitle]));
     }
 
     void saveState() {
-        KConfigGroup configGroup(config, configGroupName);
+        KConfigGroup configGroup(d->config, configGroupName);
         configGroup.writeEntry(QStringLiteral("searchWhere"), comboBoxSearchWhere->currentIndex());
         configGroup.writeEntry(QStringLiteral("searchTerm"), lineEditSearchTerm->text());
         configGroup.writeEntry(QStringLiteral("numResults"), numResultsField->value());
-        config->sync();
+        d->config->sync();
     }
 };
 #endif // HAVE_QTWIDGETS
@@ -121,7 +123,7 @@ class OnlineSearchBibsonomy::OnlineSearchBibsonomyPrivate
 {
 public:
 #ifdef HAVE_QTWIDGETS
-    OnlineSearchQueryFormBibsonomy *form;
+    OnlineSearchBibsonomy::Form *form;
 #endif // HAVE_QTWIDGETS
 
     OnlineSearchBibsonomyPrivate(OnlineSearchBibsonomy *)
@@ -223,7 +225,12 @@ void OnlineSearchBibsonomy::startSearchFromForm()
 
 QString OnlineSearchBibsonomy::label() const
 {
+#ifdef HAVE_KF5
     return i18n("Bibsonomy");
+#else // HAVE_KF5
+    //= onlinesearch-bibsonomy-label
+    return QObject::tr("Bibsonomy");
+#endif // HAVE_KF5
 }
 
 QString OnlineSearchBibsonomy::favIconUrl() const
@@ -232,10 +239,10 @@ QString OnlineSearchBibsonomy::favIconUrl() const
 }
 
 #ifdef HAVE_QTWIDGETS
-OnlineSearchQueryFormAbstract *OnlineSearchBibsonomy::customWidget(QWidget *parent)
+OnlineSearchAbstract::Form *OnlineSearchBibsonomy::customWidget(QWidget *parent)
 {
     if (d->form == nullptr)
-        d->form = new OnlineSearchBibsonomy::OnlineSearchQueryFormBibsonomy(parent);
+        d->form = new OnlineSearchBibsonomy::Form(parent);
     return d->form;
 }
 #endif // HAVE_QTWIDGETS
