@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,6 +22,7 @@
 #include <QLabel>
 #include <QFormLayout>
 #include <QSpinBox>
+#include <QLineEdit>
 #include <QIcon>
 #endif // HAVE_QTWIDGETS
 #include <QNetworkReply>
@@ -30,19 +31,19 @@
 #ifdef HAVE_KF5
 #include <KLocalizedString>
 #include <KConfigGroup>
-#include <KLineEdit>
 #else // HAVE_KF5
 #define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
-#include "file.h"
-#include "entry.h"
-#include "fileimporterbibtex.h"
+#include <File>
+#include <Entry>
+#include <FileImporterBibTeX>
 #include "internalnetworkaccessmanager.h"
+#include "onlinesearchabstract_p.h"
 #include "logging_networking.h"
 
 #ifdef HAVE_QTWIDGETS
-class OnlineSearchIngentaConnect::OnlineSearchQueryFormIngentaConnect : public OnlineSearchQueryFormAbstract
+class OnlineSearchIngentaConnect::Form : public OnlineSearchAbstract::Form
 {
     Q_OBJECT
 
@@ -50,7 +51,7 @@ private:
     QString configGroupName;
 
     void loadState() {
-        KConfigGroup configGroup(config, configGroupName);
+        KConfigGroup configGroup(d->config, configGroupName);
         lineEditFullText->setText(configGroup.readEntry(QStringLiteral("fullText"), QString()));
         lineEditTitle->setText(configGroup.readEntry(QStringLiteral("title"), QString()));
         lineEditAuthor->setText(configGroup.readEntry(QStringLiteral("author"), QString()));
@@ -63,60 +64,60 @@ private:
     }
 
 public:
-    KLineEdit *lineEditFullText;
-    KLineEdit *lineEditTitle;
-    KLineEdit *lineEditAuthor;
-    KLineEdit *lineEditAbstractKeywords;
-    KLineEdit *lineEditPublication;
-    KLineEdit *lineEditISSNDOIISBN;
-    KLineEdit *lineEditVolume;
-    KLineEdit *lineEditIssue;
+    QLineEdit *lineEditFullText;
+    QLineEdit *lineEditTitle;
+    QLineEdit *lineEditAuthor;
+    QLineEdit *lineEditAbstractKeywords;
+    QLineEdit *lineEditPublication;
+    QLineEdit *lineEditISSNDOIISBN;
+    QLineEdit *lineEditVolume;
+    QLineEdit *lineEditIssue;
     QSpinBox *numResultsField;
 
-    OnlineSearchQueryFormIngentaConnect(QWidget *widget)
-            : OnlineSearchQueryFormAbstract(widget), configGroupName(QStringLiteral("Search Engine IngentaConnect")) {
+    Form(QWidget *widget)
+            : OnlineSearchAbstract::Form(widget), configGroupName(QStringLiteral("Search Engine IngentaConnect")) {
         QFormLayout *layout = new QFormLayout(this);
         layout->setMargin(0);
 
-        lineEditFullText = new KLineEdit(this);
+        lineEditFullText = new QLineEdit(this);
         lineEditFullText->setClearButtonEnabled(true);
         layout->addRow(i18n("Full text:"), lineEditFullText);
-        connect(lineEditFullText, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditFullText, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditTitle = new KLineEdit(this);
+        lineEditTitle = new QLineEdit(this);
         lineEditTitle->setClearButtonEnabled(true);
         layout->addRow(i18n("Title:"), lineEditTitle);
-        connect(lineEditTitle, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditTitle, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditAuthor = new KLineEdit(this);
+        lineEditAuthor = new QLineEdit(this);
         lineEditAuthor->setClearButtonEnabled(true);
         layout->addRow(i18n("Author:"), lineEditAuthor);
-        connect(lineEditAuthor, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditAuthor, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditAbstractKeywords = new KLineEdit(this);
+        lineEditAbstractKeywords = new QLineEdit(this);
         lineEditAbstractKeywords->setClearButtonEnabled(true);
         layout->addRow(i18n("Abstract/Keywords:"), lineEditAbstractKeywords);
-        connect(lineEditAbstractKeywords, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditAbstractKeywords, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditPublication = new KLineEdit(this);
+        lineEditPublication = new QLineEdit(this);
         lineEditPublication->setClearButtonEnabled(true);
         layout->addRow(i18n("Publication:"), lineEditPublication);
-        connect(lineEditPublication, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditPublication, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditISSNDOIISBN = new KLineEdit(this);
+        lineEditISSNDOIISBN = new QLineEdit(this);
         lineEditISSNDOIISBN->setClearButtonEnabled(true);
         layout->addRow(i18n("ISSN/ISBN/DOI:"), lineEditISSNDOIISBN);
-        connect(lineEditISSNDOIISBN, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditISSNDOIISBN, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditVolume = new KLineEdit(this);
+        lineEditVolume = new QLineEdit(this);
         lineEditVolume->setClearButtonEnabled(true);
         layout->addRow(i18n("Volume:"), lineEditVolume);
-        connect(lineEditVolume, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditVolume, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
-        lineEditIssue = new KLineEdit(this);
+        lineEditIssue = new QLineEdit(this);
         lineEditIssue->setClearButtonEnabled(true);
         layout->addRow(i18n("Issue/Number:"), lineEditIssue);
-        connect(lineEditIssue, &KLineEdit::returnPressed, this, &OnlineSearchQueryFormIngentaConnect::returnPressed);
+        connect(lineEditIssue, &QLineEdit::returnPressed, this, &OnlineSearchIngentaConnect::Form::returnPressed);
 
         numResultsField = new QSpinBox(this);
         layout->addRow(i18n("Number of Results:"), numResultsField);
@@ -131,7 +132,7 @@ public:
 
     void copyFromEntry(const Entry &entry) override {
         lineEditTitle->setText(PlainTextValue::text(entry[Entry::ftTitle]));
-        lineEditAuthor->setText(authorLastNames(entry).join(QStringLiteral(" ")));
+        lineEditAuthor->setText(d->authorLastNames(entry).join(QStringLiteral(" ")));
         lineEditVolume->setText(PlainTextValue::text(entry[Entry::ftVolume]));
         lineEditIssue->setText(PlainTextValue::text(entry[Entry::ftNumber]));
         QString issnDoiIsbn = PlainTextValue::text(entry[Entry::ftDOI]);
@@ -150,7 +151,7 @@ public:
     }
 
     void saveState() {
-        KConfigGroup configGroup(config, configGroupName);
+        KConfigGroup configGroup(d->config, configGroupName);
         configGroup.writeEntry(QStringLiteral("fullText"), lineEditFullText->text());
         configGroup.writeEntry(QStringLiteral("title"), lineEditTitle->text());
         configGroup.writeEntry(QStringLiteral("author"), lineEditAuthor->text());
@@ -160,7 +161,7 @@ public:
         configGroup.writeEntry(QStringLiteral("volume"), lineEditVolume->text());
         configGroup.writeEntry(QStringLiteral("issue"), lineEditIssue->text());
         configGroup.writeEntry(QStringLiteral("numResults"), numResultsField->value());
-        config->sync();
+        d->config->sync();
     }
 };
 #endif // HAVE_QTWIDGETS
@@ -172,7 +173,7 @@ private:
 
 public:
 #ifdef HAVE_QTWIDGETS
-    OnlineSearchQueryFormIngentaConnect *form;
+    OnlineSearchIngentaConnect::Form *form;
 #endif // HAVE_QTWIDGETS
 
     OnlineSearchIngentaConnectPrivate(OnlineSearchIngentaConnect *)
@@ -357,7 +358,12 @@ void OnlineSearchIngentaConnect::startSearchFromForm()
 
 QString OnlineSearchIngentaConnect::label() const
 {
+#ifdef HAVE_KF5
     return i18n("IngentaConnect");
+#else // HAVE_KF5
+    //= onlinesearch-ingentaconnect-label
+    return QObject::tr("IngentaConnect");
+#endif // HAVE_KF5
 }
 
 QString OnlineSearchIngentaConnect::favIconUrl() const
@@ -366,10 +372,10 @@ QString OnlineSearchIngentaConnect::favIconUrl() const
 }
 
 #ifdef HAVE_QTWIDGETS
-OnlineSearchQueryFormAbstract *OnlineSearchIngentaConnect::customWidget(QWidget *parent)
+OnlineSearchAbstract::Form *OnlineSearchIngentaConnect::customWidget(QWidget *parent)
 {
     if (d->form == nullptr)
-        d->form = new OnlineSearchIngentaConnect::OnlineSearchQueryFormIngentaConnect(parent);
+        d->form = new OnlineSearchIngentaConnect::Form(parent);
     return d->form;
 }
 #endif // HAVE_QTWIDGETS
