@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                 2018 Alexander Dunlap <alexander.dunlap@gmail.com>      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -16,10 +16,14 @@
  *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#ifndef KBIBTEX_ONLINESEARCH_MATHSCINET_H
-#define KBIBTEX_ONLINESEARCH_MATHSCINET_H
+#ifndef KBIBTEX_NETWORKING_ONLINESEARCHMATHSCINET_H
+#define KBIBTEX_NETWORKING_ONLINESEARCHMATHSCINET_H
 
-#include "onlinesearchabstract.h"
+#include <onlinesearch/OnlineSearchAbstract>
+
+#ifdef HAVE_KF5
+#include "kbibtexnetworking_export.h"
+#endif // HAVE_KF5
 
 /**
  * @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
@@ -29,7 +33,7 @@ class KBIBTEXNETWORKING_EXPORT OnlineSearchMathSciNet : public OnlineSearchAbstr
     Q_OBJECT
 
 public:
-    explicit OnlineSearchMathSciNet(QWidget *parent);
+    explicit OnlineSearchMathSciNet(QObject *parent);
     ~OnlineSearchMathSciNet() override;
 
     void startSearch(const QMap<QString, QString> &query, int numResults) override;
@@ -50,4 +54,4 @@ private:
     OnlineSearchMathSciNetPrivate *d;
 };
 
-#endif // KBIBTEX_ONLINESEARCH_MATHSCINET_H
+#endif // KBIBTEX_NETWORKING_ONLINESEARCHMATHSCINET_H
