@@ -27,14 +27,14 @@
 
 #include <KLocalizedString>
 
-#include "fileimporterbibtex.h"
-#include "kbibtex.h"
+#include <KBibTeX>
+#include <FileImporterBibTeX>
 #include "internalnetworkaccessmanager.h"
 #include "logging_networking.h"
 
 const QString OnlineSearchMRLookup::queryUrlStem = QStringLiteral("https://mathscinet.ams.org/mrlookup");
 
-OnlineSearchMRLookup::OnlineSearchMRLookup(QWidget *parent)
+OnlineSearchMRLookup::OnlineSearchMRLookup(QObject *parent)
         : OnlineSearchAbstract(parent)
 {
     /// nothing
