@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,11 +33,11 @@
 #define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
-#include "fileimporterbibtex.h"
-#include "encoderxml.h"
-#include "xsltransform.h"
+#include <KBibTeX>
+#include <FileImporterBibTeX>
+#include <EncoderXML>
+#include <XSLTransform>
 #include "internalnetworkaccessmanager.h"
-#include "kbibtex.h"
 #include "logging_networking.h"
 
 class OnlineSearchScienceDirect::OnlineSearchScienceDirectPrivate
@@ -118,7 +118,7 @@ public:
             entry->insert(Entry::ftUrl, Value() << QSharedPointer<VerbatimText>(new VerbatimText(url)));
 
         const QJsonObject pages = object.value(QStringLiteral("pages")).toObject();
-        bool firstPageOk = false, lastPageOk = false;;
+        bool firstPageOk = false, lastPageOk = false;
         const int firstPage = pages.value(QStringLiteral("first")).toString().toInt(&firstPageOk);
         const int lastPage = firstPageOk ? pages.value(QStringLiteral("last")).toString().toInt(&lastPageOk) : -1;
         if (firstPageOk && lastPageOk && firstPage <= lastPage)
@@ -211,12 +211,17 @@ void OnlineSearchScienceDirect::startSearch(const QMap<QString, QString> &query,
 
 QString OnlineSearchScienceDirect::label() const
 {
+#ifdef HAVE_KF5
     return i18n("ScienceDirect");
+#else // HAVE_KF5
+    //= onlinesearch-sciencedirect-label
+    return QObject::tr("ScienceDirect");
+#endif // HAVE_KF5
 }
 
 QString OnlineSearchScienceDirect::favIconUrl() const
 {
-    return QStringLiteral("https://sdfestaticassets-us-east-1.sciencedirectassets.com/shared-assets/11/images/favSD.ico");
+    return QStringLiteral("https://sdfestaticassets-eu-west-1.sciencedirectassets.com/shared-assets/18/images/favSD.ico");
 }
 
 QUrl OnlineSearchScienceDirect::homepage() const
