@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2022 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,9 +27,11 @@
 #include <QRegularExpressionMatch>
 #include <QFile>
 
+#ifdef HAVE_KF5
 #include <KLocalizedString>
+#endif // HAVE_KF5
 
-#include "fileimporterbibtex.h"
+#include <FileImporterBibTeX>
 #include "internalnetworkaccessmanager.h"
 #include "logging_networking.h"
 
@@ -95,7 +97,7 @@ const QUrl OnlineSearchSOANASAADS::Private::apiSearchUrl(QStringLiteral("https:/
 const QUrl OnlineSearchSOANASAADS::Private::apiExportUrl(QStringLiteral("https://api.adsabs.harvard.edu/v1/export/bibtexabs"));
 const QByteArray OnlineSearchSOANASAADS::Private::apiKey(InternalNetworkAccessManager::reverseObfuscate("\xa3\xe4\xf4\x9b\xe9\xd8\xdb\xb3\x74\x3a\x28\x61\x1d\x51\x35\x6d\x7b\x48\xd0\x8a\xe4\xd7\x82\xfa\x1d\x4e\x33\x76\xca\x90\x65\x52\xd\x5e\x73\x1b\x94\xf7\x79\x49\xdf\xa6\xb0\xe4\x9c\xc6\x8a\xbc\x6e\x24\x56\x5\xa2\xd2\xaf\xf7\xc4\xf4\x8\x5a\x62\x54\x60\x21\x92\xf7\xc6\xa7\xe6\xaf\x68\x5b\x8c\xcb\xdd\xb1\x5c\x2a\xd\x5c").toLatin1());
 
-OnlineSearchSOANASAADS::OnlineSearchSOANASAADS(QWidget *parent)
+OnlineSearchSOANASAADS::OnlineSearchSOANASAADS(QObject *parent)
         : OnlineSearchAbstract(parent), d(new Private)
 {
     /// nothing
