@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,7 +18,6 @@
 #include "collectionmodel.h"
 
 #include <QHash>
-
 #include <QIcon>
 
 #include "zotero/collection.h"
@@ -44,7 +43,9 @@ CollectionModel::CollectionModel(Collection *collection, QObject *parent)
         : QAbstractItemModel(parent), d(new Zotero::CollectionModel::Private(collection, this))
 {
     beginResetModel();
-    connect(collection, &Collection::finishedLoading, this, &CollectionModel::fetchingDone);
+    connect(collection, &Collection::finishedLoading, this, [this]() {
+        endResetModel();
+    });
 }
 
 QVariant CollectionModel::data(const QModelIndex &index, int role) const
@@ -81,7 +82,7 @@ QModelIndex CollectionModel::index(int row, int column, const QModelIndex &paren
         return QModelIndex();
 
     if (parent == QModelIndex()) { ///< root node
-        const QModelIndex result = createIndex(row, column, (quintptr)0);
+        const QModelIndex result = createIndex(row, column, static_cast<quintptr>(0));
         d->collectionIdToModelIndex.insert(d->collection->collectionFromNumericId(0), result);
         return result;
     }
@@ -135,8 +136,3 @@ bool CollectionModel::hasChildren(const QModelIndex &parent) const
 
     return rowCount(parent) > 0;
 }
-
-void CollectionModel::fetchingDone()
-{
-    endResetModel();
-}
