@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,8 +25,6 @@
 #include <QApplication>
 #include <QLayout>
 #include <QKeyEvent>
-#include <QSignalMapper>
-#include <QMimeDatabase>
 #include <QMimeType>
 #include <QPointer>
 #include <QFileSystemWatcher>
@@ -36,7 +34,9 @@
 #include <QPushButton>
 #include <QTemporaryFile>
 #include <QTimer>
+#include <QStandardPaths>
 
+#include <kio_version.h>
 #include <KMessageBox> // FIXME deprecated
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -44,62 +44,58 @@
 #include <KActionMenu>
 #include <KSelectAction>
 #include <KToggleAction>
-#include <KSharedConfig>
-#include <KConfigGroup>
+#if KIO_VERSION >= 0x054700 // >= 5.71.0
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
+#else // < 5.71.0
 #include <KRun>
+#endif // KIO_VERSION >= 0x054700
 #include <KPluginFactory>
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
 #include <KIO/Job>
 #include <KJobWidgets>
-#include <kio_version.h>
 
-#include "file.h"
-#include "macro.h"
-#include "preamble.h"
-#include "comment.h"
-#include "fileinfo.h"
-#include "fileexporterbibtexoutput.h"
-#include "fileimporterbibtex.h"
-#include "fileexporterbibtex.h"
-#include "fileimporterris.h"
-#include "fileimporterbibutils.h"
-#include "fileexporterris.h"
-#include "fileexporterbibutils.h"
-#include "fileimporterpdf.h"
-#include "fileexporterps.h"
-#include "fileexporterpdf.h"
-#include "fileexporterrtf.h"
-#include "fileexporterbibtex2html.h"
-#include "fileexporterxml.h"
-#include "fileexporterxslt.h"
-#include "models/filemodel.h"
-#include "filesettingswidget.h"
-#include "filterbar.h"
-#include "findduplicatesui.h"
-#include "lyx.h"
-#include "preferences.h"
-#include "settingscolorlabelwidget.h"
-#include "settingsfileexporterpdfpswidget.h"
-#include "findpdfui.h"
-#include "valuelistmodel.h"
-#include "clipboard.h"
-#include "idsuggestions.h"
-#include "fileview.h"
-#include "browserextension.h"
-#include "logging_parts.h"
+#include <Preferences>
+#include <File>
+#include <Macro>
+#include <Preamble>
+#include <Comment>
+#include <FileInfo>
+#include <FileExporterBibTeXOutput>
+#include <FileImporterBibTeX>
+#include <FileExporterBibTeX>
+#include <FileImporterRIS>
+#include <FileImporterBibUtils>
+#include <FileExporterRIS>
+#include <FileExporterBibUtils>
+#include <FileImporterPDF>
+#include <FileExporterPS>
+#include <FileExporterPDF>
+#include <FileExporterRTF>
+#include <FileExporterBibTeX2HTML>
+#include <FileExporterXML>
+#include <FileExporterXSLT>
+#include <models/FileModel>
+#include <IdSuggestions>
+#include <LyX>
+#include <UrlChecker>
+#include <widgets/FileSettingsWidget>
+#include <widgets/FilterBar>
+#include <element/FindPDFUI>
+#include <file/FileView>
+#include <file/FindDuplicatesUI>
+#include <file/Clipboard>
+#include <preferences/SettingsColorLabelWidget>
+#include <preferences/SettingsFileExporterPDFPSWidget>
+#include <ValueListModel>
+#include "logging_part.h"
 
 static const char RCFileName[] = "kbibtexpartui.rc";
-static const int smEntry = 1;
-static const int smComment = 2;
-static const int smPreamble = 3;
-static const int smMacro = 4;
-
 class KBibTeXPart::KBibTeXPartPrivate
 {
 private:
     KBibTeXPart *p;
-    KSharedConfigPtr config;
 
     /**
      * Modifies a given URL to become a "backup" filename/URL.
@@ -126,11 +122,8 @@ public:
     PartWidget *partWidget;
     FileModel *model;
     SortFilterFileModel *sortFilterProxyModel;
-    QSignalMapper *signalMapperNewElement;
     QAction *editCutAction, *editDeleteAction, *editCopyAction, *editPasteAction, *editCopyReferencesAction, *elementEditAction, *elementViewDocumentAction, *fileSaveAction, *elementFindPDFAction, *entryApplyDefaultFormatString;
     QMenu *viewDocumentMenu;
-    QSignalMapper *signalMapperViewDocument;
-    QSet<QObject *> signalMapperViewDocumentSenders;
     bool isSaveAsOperation;
     LyX *lyx;
     FindDuplicatesUI *findDuplicatesUI;
@@ -139,8 +132,7 @@ public:
     QFileSystemWatcher fileSystemWatcher;
 
     KBibTeXPartPrivate(QWidget *parentWidget, KBibTeXPart *parent)
-            : p(parent), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), bibTeXFile(nullptr), model(nullptr), sortFilterProxyModel(nullptr), signalMapperNewElement(new QSignalMapper(parent)), viewDocumentMenu(new QMenu(i18n("View Document"), parent->widget())), signalMapperViewDocument(new QSignalMapper(parent)), isSaveAsOperation(false), fileSystemWatcher(p) {
-        connect(signalMapperViewDocument, static_cast<void(QSignalMapper::*)(QObject *)>(&QSignalMapper::mapped), p, &KBibTeXPart::elementViewDocumentMenu);
+            : p(parent), bibTeXFile(nullptr), model(nullptr), sortFilterProxyModel(nullptr), viewDocumentMenu(new QMenu(i18n("View Document"), parent->widget())), isSaveAsOperation(false), fileSystemWatcher(p) {
         connect(&fileSystemWatcher, &QFileSystemWatcher::fileChanged, p, &KBibTeXPart::fileExternallyChange);
 
         partWidget = new PartWidget(parentWidget);
@@ -153,9 +145,7 @@ public:
     ~KBibTeXPartPrivate() {
         delete bibTeXFile;
         delete model;
-        delete signalMapperNewElement;
         delete viewDocumentMenu;
-        delete signalMapperViewDocument;
         delete findDuplicatesUI;
     }
 
@@ -187,20 +177,23 @@ public:
         QMenu *newElementMenu = new QMenu(newElementAction->text(), p->widget());
         newElementAction->setMenu(newElementMenu);
         connect(newElementAction, &QAction::triggered, p, &KBibTeXPart::newEntryTriggered);
-        QAction *newEntry = newElementMenu->addAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New entry"));
+
+        QAction *newEntry = new QAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New entry"), newElementAction);
+        newElementMenu->addAction(newEntry);
         p->actionCollection()->setDefaultShortcut(newEntry, Qt::CTRL + Qt::SHIFT + Qt::Key_N);
-        connect(newEntry, &QAction::triggered, signalMapperNewElement, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-        signalMapperNewElement->setMapping(newEntry, smEntry);
-        QAction *newComment = newElementMenu->addAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New comment"));
-        connect(newComment, &QAction::triggered, signalMapperNewElement, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-        signalMapperNewElement->setMapping(newComment, smComment);
-        QAction *newMacro = newElementMenu->addAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New macro"));
-        connect(newMacro, &QAction::triggered, signalMapperNewElement, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-        signalMapperNewElement->setMapping(newMacro, smMacro);
-        QAction *newPreamble = newElementMenu->addAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New preamble"));
-        connect(newPreamble, &QAction::triggered, signalMapperNewElement, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-        signalMapperNewElement->setMapping(newPreamble, smPreamble);
-        connect(signalMapperNewElement, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), p, &KBibTeXPart::newElementTriggered);
+        connect(newEntry, &QAction::triggered, p, &KBibTeXPart::newEntryTriggered);
+
+        QAction *newComment = new QAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New comment"), newElementAction);
+        newElementMenu->addAction(newComment);
+        connect(newComment, &QAction::triggered, p, &KBibTeXPart::newCommentTriggered);
+
+        QAction *newMacro = new QAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New macro"), newElementAction);
+        newElementMenu->addAction(newMacro);
+        connect(newMacro, &QAction::triggered, p, &KBibTeXPart::newMacroTriggered);
+
+        QAction *newPreamble = new QAction(QIcon::fromTheme(QStringLiteral("address-book-new")), i18n("New preamble"), newElementAction);
+        newElementMenu->addAction(newPreamble);
+        connect(newPreamble, &QAction::triggered, p, &KBibTeXPart::newPreambleTriggered);
 
         /// Action to edit an element
         elementEditAction = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Edit Element"), p);
@@ -228,8 +221,10 @@ public:
         Clipboard *clipboard = new Clipboard(partWidget->fileView());
 
         /// Actions to cut and copy selected elements as BibTeX code
-        editCutAction = p->actionCollection()->addAction(KStandardAction::Cut, clipboard, SLOT(cut()));
-        editCopyAction = p->actionCollection()->addAction(KStandardAction::Copy, clipboard, SLOT(copy()));
+        editCutAction = p->actionCollection()->addAction(KStandardAction::Cut);
+        connect(editCutAction, &QAction::triggered, clipboard, &Clipboard::cut);
+        editCopyAction = p->actionCollection()->addAction(KStandardAction::Copy);
+        connect(editCopyAction, &QAction::triggered, clipboard, &Clipboard::copy);
 
         /// Action to copy references, e.g. '\cite{fordfulkerson1959}'
         editCopyReferencesAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy References"), p);
@@ -238,7 +233,8 @@ public:
         connect(editCopyReferencesAction, &QAction::triggered, clipboard, &Clipboard::copyReferences);
 
         /// Action to paste BibTeX code
-        editPasteAction = p->actionCollection()->addAction(KStandardAction::Paste, clipboard, SLOT(paste()));
+        action = editPasteAction = p->actionCollection()->addAction(KStandardAction::Paste);
+        connect(action, &QAction::triggered, clipboard, &Clipboard::paste);
 
         /// Action to delete selected rows/elements
         editDeleteAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-table-delete-row")), i18n("Delete"), p);
@@ -274,9 +270,8 @@ public:
     }
 
     FileImporter *fileImporterFactory(const QUrl &url) {
-        QString ending = url.path().toLower();
-        const auto pos = ending.lastIndexOf(QStringLiteral("."));
-        ending = ending.mid(pos + 1);
+        const QFileInfo filenameInfo(url.fileName());
+        const QString ending = filenameInfo.completeSuffix();
 
         if (ending == QStringLiteral("pdf")) {
             return new FileImporterPDF(p);
@@ -284,11 +279,11 @@ public:
             return new FileImporterRIS(p);
         } else if (BibUtils::available() && ending == QStringLiteral("isi")) {
             FileImporterBibUtils *fileImporterBibUtils = new FileImporterBibUtils(p);
-            fileImporterBibUtils->setFormat(BibUtils::ISI);
+            fileImporterBibUtils->setFormat(BibUtils::Format::ISI);
             return fileImporterBibUtils;
         } else {
             FileImporterBibTeX *fileImporterBibTeX = new FileImporterBibTeX(p);
-            fileImporterBibTeX->setCommentHandling(FileImporterBibTeX::KeepComments);
+            fileImporterBibTeX->setCommentHandling(FileImporterBibTeX::CommentHandling::Keep);
             return fileImporterBibTeX;
         }
     }
@@ -306,14 +301,14 @@ public:
             return new FileExporterPS(p);
         } else if (BibUtils::available() && ending == QStringLiteral("isi")) {
             FileExporterBibUtils *fileExporterBibUtils = new FileExporterBibUtils(p);
-            fileExporterBibUtils->setFormat(BibUtils::ISI);
+            fileExporterBibUtils->setFormat(BibUtils::Format::ISI);
             return fileExporterBibUtils;
         } else if (ending == QStringLiteral("rtf")) {
             return new FileExporterRTF(p);
         } else if (ending == QStringLiteral("html") || ending == QStringLiteral("htm")) {
             return new FileExporterBibTeX2HTML(p);
         } else if (ending == QStringLiteral("bbl")) {
-            return new FileExporterBibTeXOutput(FileExporterBibTeXOutput::BibTeXBlockList, p);
+            return new FileExporterBibTeXOutput(FileExporterBibTeXOutput::OutputType::BibTeXBlockList, p);
         } else {
             return new FileExporterBibTeX(p);
         }
@@ -327,7 +322,6 @@ public:
                 return result;
             ++i;
         }
-        return QString();
     }
 
     void initializeNew() {
@@ -354,7 +348,7 @@ public:
                 if (!path.isEmpty())
                     fileSystemWatcher.removePath(path);
                 else
-                    qCWarning(LOG_KBIBTEX_PARTS) << "No filename to stop watching";
+                    qCWarning(LOG_KBIBTEX_PART) << "No filename to stop watching";
             }
             delete bibTeXFile;
             bibTeXFile = nullptr;
@@ -362,7 +356,7 @@ public:
 
         QFile inputfile(localFilePath);
         if (!inputfile.open(QIODevice::ReadOnly)) {
-            qCWarning(LOG_KBIBTEX_PARTS) << "Opening file failed, creating new one instead:" << url.toDisplayString() << "aka" << localFilePath;
+            qCWarning(LOG_KBIBTEX_PART) << "Opening file failed, creating new one instead:" << url.toDisplayString() << "aka" << localFilePath;
             qApp->restoreOverrideCursor();
             /// Opening file failed, creating new one instead
             initializeNew();
@@ -376,7 +370,7 @@ public:
         delete importer;
 
         if (bibTeXFile == nullptr) {
-            qCWarning(LOG_KBIBTEX_PARTS) << "Opening file failed, creating new one instead:" << url.toDisplayString() << "aka" << localFilePath;
+            qCWarning(LOG_KBIBTEX_PART) << "Opening file failed, creating new one instead:" << url.toDisplayString() << "aka" << localFilePath;
             qApp->restoreOverrideCursor();
             /// Opening file failed, creating new one instead
             initializeNew();
@@ -402,27 +396,29 @@ public:
 
     void makeBackup(const QUrl &url) const {
         /// Fetch settings from configuration
-        KConfigGroup configGroup(config, Preferences::groupGeneral);
-        const Preferences::BackupScope backupScope = static_cast<Preferences::BackupScope>(configGroup.readEntry(Preferences::keyBackupScope, static_cast<int>(Preferences::defaultBackupScope)));
-        const int numberOfBackups = configGroup.readEntry(Preferences::keyNumberOfBackups, Preferences::defaultNumberOfBackups);
+        const int numberOfBackups = Preferences::instance().numberOfBackups();
 
         /// Stop right here if no backup is requested
-        if (backupScope == Preferences::NoBackup)
+        if (Preferences::instance().backupScope() == Preferences::BackupScope::None)
             return;
 
         /// For non-local files, proceed only if backups to remote storage is allowed
-        if (backupScope != Preferences::BothLocalAndRemote && !url.isLocalFile())
+        if (Preferences::instance().backupScope() != Preferences::BackupScope::BothLocalAndRemote && !url.isLocalFile())
             return;
 
         /// Do not make backup copies if destination file does not exist yet
+#if KIO_VERSION >= 0x054500 // >= 5.69.0
+        KIO::StatJob *statJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails /** not details necessary, just need to know if file exists */, KIO::HideProgressInfo);
+#else // KIO_VERSION < 0x054500 // < 5.69.0
         KIO::StatJob *statJob = KIO::stat(url, KIO::StatJob::DestinationSide, 0 /** not details necessary, just need to know if file exists */, KIO::HideProgressInfo);
+#endif // KIO_VERSION
         KJobWidgets::setWindow(statJob, p->widget());
         statJob->exec();
         if (statJob->error() == KIO::ERR_DOES_NOT_EXIST)
             return;
         else if (statJob->error() != KIO::Job::NoError) {
             /// Something else went wrong, quit with error
-            qCWarning(LOG_KBIBTEX_PARTS) << "Probing" << url.toDisplayString() << "failed:" << statJob->errorString();
+            qCWarning(LOG_KBIBTEX_PART) << "Probing" << url.toDisplayString() << "failed:" << statJob->errorString();
             return;
         }
 
@@ -434,7 +430,11 @@ public:
             QUrl olderBackupUrl = url;
             constructBackupUrl(level, olderBackupUrl);
 
+#if KIO_VERSION >= 0x054500 // >= 5.69.0
+            statJob = KIO::statDetails(newerBackupUrl, KIO::StatJob::DestinationSide, KIO::StatNoDetails /** not details necessary, just need to know if file exists */, KIO::HideProgressInfo);
+#else // KIO_VERSION < 0x054500 // < 5.69.0
             statJob = KIO::stat(newerBackupUrl, KIO::StatJob::DestinationSide, 0 /** not details necessary, just need to know if file exists */, KIO::HideProgressInfo);
+#endif // KIO_VERSION
             KJobWidgets::setWindow(statJob, p->widget());
             if (statJob->exec() && statJob->error() == KIO::Job::NoError) {
                 KIO::CopyJob *moveJob = nullptr; ///< guaranteed to be initialized in either branch of the following code
@@ -496,7 +496,11 @@ public:
         QPointer<QFileDialog> saveDlg = new QFileDialog(p->widget(), i18n("Save file") /* TODO better text */, startDir, supportedMimeTypes);
         /// Setting list of mime types for the second time,
         /// essentially calling this function only to set the "default mime type" parameter
+#if QT_VERSION >= 0x050e00
+        saveDlg->setMimeTypeFilters(supportedMimeTypes.split(QLatin1Char(' '), Qt::SkipEmptyParts));
+#else // QT_VERSION < 0x050e00
         saveDlg->setMimeTypeFilters(supportedMimeTypes.split(QLatin1Char(' '), QString::SkipEmptyParts));
+#endif // QT_VERSION >= 0x050e00
         /// Setting the dialog into "Saving" mode make the "add extension" checkbox available
         saveDlg->setAcceptMode(QFileDialog::AcceptSave);
         saveDlg->setDefaultSuffix(QStringLiteral("bib"));
@@ -547,7 +551,6 @@ public:
 
                 if (dlg->exec() == QDialog::Accepted)
                     settingsWidget->saveState();
-                fet->reloadConfig();
                 delete dlg;
             }
         }
@@ -558,18 +561,18 @@ public:
     bool saveFile(QFile &file, FileExporter *exporter, QStringList *errorLog = nullptr) {
         SortFilterFileModel *model = qobject_cast<SortFilterFileModel *>(partWidget->fileView()->model());
         Q_ASSERT_X(model != nullptr, "FileExporter *KBibTeXPart::KBibTeXPartPrivate:saveFile(...)", "SortFilterFileModel *model from editor->model() is invalid");
+        Q_ASSERT_X(model->fileSourceModel()->bibliographyFile() == bibTeXFile, "FileExporter *KBibTeXPart::KBibTeXPartPrivate:saveFile(...)", "SortFilterFileModel's BibTeX File does not match Part's BibTeX File");
 
-        return exporter->save(&file, model->fileSourceModel()->bibliographyFile(), errorLog);
+        return exporter->save(&file, bibTeXFile, errorLog);
     }
 
     bool saveFile(const QUrl &url) {
         bool result = false;
-        Q_ASSERT_X(!url.isEmpty(), "bool KBibTeXPart::KBibTeXPartPrivate:saveFile(const QUrl &url)", "url is not allowed to be empty");
+        Q_ASSERT_X(url.isValid(), "bool KBibTeXPart::KBibTeXPartPrivate:saveFile(const QUrl &url)", "url must be valid");
 
         /// Extract filename extension (e.g. 'bib') to determine which FileExporter to use
-        static const QRegularExpression suffixRegExp(QStringLiteral("\\.([^.]{1,4})$"));
-        const QRegularExpressionMatch suffixRegExpMatch = suffixRegExp.match(url.fileName());
-        const QString ending = suffixRegExpMatch.hasMatch() ? suffixRegExpMatch.captured(1) : QStringLiteral("bib");
+        const QFileInfo filenameInfo(url.fileName());
+        const QString ending = filenameInfo.completeSuffix();
         FileExporter *exporter = saveFileExporter(ending);
 
         /// String list to collect error message from FileExporer
@@ -594,7 +597,10 @@ public:
                 if (file.open(QIODevice::WriteOnly)) {
                     result = saveFile(file, exporter, &errorLog);
                     file.close();
-                }
+                    if (!result)
+                        errorLog.append(i18n("Could not write bibliographic data to file."));
+                } else
+                    errorLog.append(i18n("Could not open local file '%1' for writing.", filename));
             }
         } else {
             /// URL points to a remote location
@@ -615,8 +621,12 @@ public:
                     KIO::CopyJob *copyJob = KIO::copy(QUrl::fromLocalFile(temporaryFile.fileName()), url, KIO::HideProgressInfo | KIO::Overwrite);
                     KJobWidgets::setWindow(copyJob, p->widget());
                     result &= copyJob->exec() && copyJob->error() == KIO::Job::NoError;
-                }
-            }
+                    if (!result)
+                        errorLog.append(i18n("Failed to upload temporary file to final destination '%1'", url.toDisplayString()));
+                } else
+                    errorLog.append(i18n("Could not write bibliographic data to temporary file."));
+            } else
+                errorLog.append(i18n("Could not open temporary file for writing."));
         }
 
         qApp->restoreOverrideCursor();
@@ -627,6 +637,8 @@ public:
             QString msg = i18n("Saving the bibliography to file '%1' failed.", url.toDisplayString());
             if (errorLog.isEmpty())
                 KMessageBox::error(p->widget(), msg, i18n("Saving bibliography failed"));
+            else if (errorLog.size() == 1)
+                KMessageBox::error(p->widget(), msg, i18n("Saving bibliography failed:") + QStringLiteral("\n\n") + errorLog.first());
             else {
                 msg += QLatin1String("\n\n");
                 msg += i18n("The following output was generated by the export filter:");
@@ -647,25 +659,13 @@ public:
         viewDocumentMenu->clear();
         int result = 0; ///< Initially, no references are known
 
-        File *bibliographyFile = partWidget != nullptr && partWidget->fileView() != nullptr && partWidget->fileView()->fileModel() != nullptr ? partWidget->fileView()->fileModel()->bibliographyFile() : nullptr;
-        if (bibliographyFile == nullptr) return result;
-
-        /// Clean signal mapper of old mappings
-        /// as stored in QSet signalMapperViewDocumentSenders
-        /// and identified by their QAction*'s
-        QSet<QObject *>::Iterator it = signalMapperViewDocumentSenders.begin();
-        while (it != signalMapperViewDocumentSenders.end()) {
-            signalMapperViewDocument->removeMappings(*it);
-            it = signalMapperViewDocumentSenders.erase(it);
-        }
-
         /// Retrieve Entry object of currently selected line
         /// in main list view
         QSharedPointer<const Entry> entry = partWidget->fileView()->currentElement().dynamicCast<const Entry>();
         /// Test and continue if there was an Entry to retrieve
         if (!entry.isNull()) {
             /// Get list of URLs associated with this entry
-            const auto urlList = FileInfo::entryUrls(entry, bibliographyFile->property(File::Url).toUrl(), FileInfo::TestExistenceYes);
+            const auto urlList = FileInfo::entryUrls(entry, bibTeXFile->property(File::Url).toUrl(), FileInfo::TestExistence::Yes);
             if (!urlList.isEmpty()) {
                 /// Memorize first action, necessary to set menu title
                 QAction *firstAction = nullptr;
@@ -677,14 +677,13 @@ public:
                     /// Build a nice menu item (label, icon, ...)
                     const QFileInfo fi(url.toLocalFile());
                     const QString label = QString(QStringLiteral("%1 [%2]")).arg(fi.fileName(), fi.absolutePath());
-                    QMimeDatabase db;
-                    QAction *action = new QAction(QIcon::fromTheme(db.mimeTypeForUrl(url).iconName()), label, p);
-                    action->setData(fi.absoluteFilePath());
+                    QAction *action = new QAction(QIcon::fromTheme(FileInfo::mimeTypeForUrl(url).iconName()), label, p);
+                    action->setData(QUrl::fromLocalFile(fi.absoluteFilePath()));
                     action->setToolTip(fi.absoluteFilePath());
-                    /// Register action at signal handler to open URL when triggered
-                    connect(action, &QAction::triggered, signalMapperViewDocument, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-                    signalMapperViewDocument->setMapping(action, action);
-                    signalMapperViewDocumentSenders.insert(action);
+                    /// Open URL when action is triggered
+                    connect(action, &QAction::triggered, p, [this, fi]() {
+                        elementViewDocumentMenu(QUrl::fromLocalFile(fi.absoluteFilePath()));
+                    });
                     viewDocumentMenu->addAction(action);
                     /// Memorize first action
                     if (firstAction == nullptr) firstAction = action;
@@ -703,14 +702,13 @@ public:
 
                     /// Build a nice menu item (label, icon, ...)
                     const QString prettyUrl = url.toDisplayString();
-                    QMimeDatabase db;
-                    QAction *action = new QAction(QIcon::fromTheme(db.mimeTypeForUrl(url).iconName()), prettyUrl, p);
-                    action->setData(prettyUrl);
+                    QAction *action = new QAction(QIcon::fromTheme(FileInfo::mimeTypeForUrl(url).iconName()), prettyUrl, p);
+                    action->setData(url);
                     action->setToolTip(prettyUrl);
-                    /// Register action at signal handler to open URL when triggered
-                    connect(action, &QAction::triggered, signalMapperViewDocument, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-                    signalMapperViewDocument->setMapping(action, action);
-                    signalMapperViewDocumentSenders.insert(action);
+                    /// Open URL when action is triggered
+                    connect(action, &QAction::triggered, p, [this, url]() {
+                        elementViewDocumentMenu(url);
+                    });
                     viewDocumentMenu->addAction(action);
                     /// Memorize first action
                     if (firstAction == nullptr) firstAction = action;
@@ -730,21 +728,32 @@ public:
     }
 
     void readConfiguration() {
-        /// Fetch settings from configuration
-        KConfigGroup configGroup(config, Preferences::groupUserInterface);
-        const Preferences::ElementDoubleClickAction doubleClickAction = static_cast<Preferences::ElementDoubleClickAction>(configGroup.readEntry(Preferences::keyElementDoubleClickAction, static_cast<int>(Preferences::defaultElementDoubleClickAction)));
-
         disconnect(partWidget->fileView(), &FileView::elementExecuted, partWidget->fileView(), &FileView::editElement);
         disconnect(partWidget->fileView(), &FileView::elementExecuted, p, &KBibTeXPart::elementViewDocument);
-        switch (doubleClickAction) {
-        case Preferences::ActionOpenEditor:
+        switch (Preferences::instance().fileViewDoubleClickAction()) {
+        case Preferences::FileViewDoubleClickAction::OpenEditor:
             connect(partWidget->fileView(), &FileView::elementExecuted, partWidget->fileView(), &FileView::editElement);
             break;
-        case Preferences::ActionViewDocument:
+        case Preferences::FileViewDoubleClickAction::ViewDocument:
             connect(partWidget->fileView(), &FileView::elementExecuted, p, &KBibTeXPart::elementViewDocument);
             break;
         }
     }
+
+    void elementViewDocumentMenu(const QUrl &url)
+    {
+        const QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
+        const QString mimeTypeName = mimeType.name();
+        /// Ask KDE subsystem to open url in viewer matching mime type
+#if KIO_VERSION < 0x054700 // < 5.71.0
+        KRun::runUrl(url, mimeTypeName, p->widget(), KRun::RunFlags());
+#else // KIO_VERSION < 0x054700 // >= 5.71.0
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimeTypeName);
+        job->setUiDelegate(new KIO::JobUiDelegate());
+        job->start();
+#endif // KIO_VERSION < 0x054700
+    }
+
 };
 
 KBibTeXPart::KBibTeXPart(QWidget *parentWidget, QObject *parent, const KAboutData &componentData)
@@ -759,8 +768,6 @@ KBibTeXPart::KBibTeXPart(QWidget *parentWidget, QObject *parent, const KAboutDat
 
     setXMLFile(RCFileName);
 
-    new BrowserExtension(this);
-
     NotificationHub::registerNotificationListener(this, NotificationHub::EventConfigurationChanged);
     d->readConfiguration();
 
@@ -789,7 +796,7 @@ bool KBibTeXPart::saveFile()
 {
     Q_ASSERT_X(isReadWrite(), "bool KBibTeXPart::saveFile()", "Trying to save although document is in read-only mode");
 
-    if (url().isEmpty())
+    if (!url().isValid())
         return documentSaveAs();
 
     /// If the current file is "watchable" (i.e. a local file),
@@ -799,7 +806,7 @@ bool KBibTeXPart::saveFile()
     if (!watchableFilename.isEmpty())
         d->fileSystemWatcher.removePath(watchableFilename);
     else
-        qCWarning(LOG_KBIBTEX_PARTS) << "watchableFilename is Empty";
+        qCWarning(LOG_KBIBTEX_PART) << "watchableFilename is Empty";
 
     const bool saveOperationSuccess = d->saveFile(url());
 
@@ -814,7 +821,7 @@ bool KBibTeXPart::saveFile()
             d->fileSystemWatcher.addPath(watchableFilename);
         });
     } else
-        qCWarning(LOG_KBIBTEX_PARTS) << "watchableFilename is Empty";
+        qCWarning(LOG_KBIBTEX_PART) << "watchableFilename is Empty";
 
     if (!saveOperationSuccess) {
         KMessageBox::error(widget(), i18n("The document could not be saved, as it was not possible to write to '%1'.\n\nCheck that you have write access to this file or that enough disk space is available.", url().toDisplayString()));
@@ -848,9 +855,9 @@ bool KBibTeXPart::documentSaveAs()
         if (!path.isEmpty())
             d->fileSystemWatcher.removePath(path);
         else
-            qCWarning(LOG_KBIBTEX_PARTS) << "No filename to stop watching";
+            qCWarning(LOG_KBIBTEX_PART) << "No filename to stop watching";
     } else
-        qCWarning(LOG_KBIBTEX_PARTS) << "Not removing" << url().url(QUrl::PreferLocalFile) << "from fileSystemWatcher";
+        qCWarning(LOG_KBIBTEX_PART) << "Not removing" << url().url(QUrl::PreferLocalFile) << "from fileSystemWatcher";
 
     // TODO how does SaveAs dialog know which mime types to support?
     if (KParts::ReadWritePart::saveAs(newUrl))
@@ -879,9 +886,8 @@ void KBibTeXPart::elementViewDocument()
     /// Go through all actions (i.e. document URLs) for this element
     for (const QAction *action : actionList) {
         /// Make URL from action's data ...
-        const QString actionData = action->data().toString();
-        if (actionData.isEmpty()) continue; ///< No URL from empty string
-        const QUrl tmpUrl = QUrl::fromUserInput(actionData);
+        const QUrl tmpUrl = action->data().toUrl();
+        if (!tmpUrl.isValid()) continue;
         /// ... but skip this action if the URL is invalid
         if (!tmpUrl.isValid()) continue;
         if (tmpUrl.isLocalFile()) {
@@ -901,30 +907,16 @@ void KBibTeXPart::elementViewDocument()
         QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
         const QString mimeTypeName = mimeType.name();
         /// Ask KDE subsystem to open url in viewer matching mime type
-#if KIO_VERSION < 0x051f00 // < 5.31.0
-        KRun::runUrl(url, mimeTypeName, widget(), false, false);
-#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+#if KIO_VERSION < 0x054700 // < 5.71.0
         KRun::runUrl(url, mimeTypeName, widget(), KRun::RunFlags());
-#endif // KIO_VERSION < 0x051f00
+#else // KIO_VERSION < 0x054700 // >= 5.71.0
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimeTypeName);
+        job->setUiDelegate(new KIO::JobUiDelegate());
+        job->start();
+#endif // KIO_VERSION < 0x054700
     }
 }
 
-void KBibTeXPart::elementViewDocumentMenu(QObject *obj)
-{
-    QString text = static_cast<QAction *>(obj)->data().toString(); ///< only a QAction will be passed along
-
-    /// Guess mime type for url to open
-    QUrl url{QUrl::fromUserInput(text)};
-    QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
-    const QString mimeTypeName = mimeType.name();
-    /// Ask KDE subsystem to open url in viewer matching mime type
-#if KIO_VERSION < 0x051f00 // < 5.31.0
-    KRun::runUrl(url, mimeTypeName, widget(), false, false);
-#else // KIO_VERSION < 0x051f00 // >= 5.31.0
-    KRun::runUrl(url, mimeTypeName, widget(), KRun::RunFlags());
-#endif // KIO_VERSION < 0x051f00
-}
-
 void KBibTeXPart::elementFindPDF()
 {
     QModelIndexList mil = d->partWidget->fileView()->selectionModel()->selectedRows();
@@ -966,23 +958,6 @@ bool KBibTeXPart::openFile()
     return success;
 }
 
-void KBibTeXPart::newElementTriggered(int event)
-{
-    switch (event) {
-    case smComment:
-        newCommentTriggered();
-        break;
-    case smMacro:
-        newMacroTriggered();
-        break;
-    case smPreamble:
-        newPreambleTriggered();
-        break;
-    default:
-        newEntryTriggered();
-    }
-}
-
 void KBibTeXPart::newEntryTriggered()
 {
     QSharedPointer<Entry> newEntry = QSharedPointer<Entry>(new Entry(QStringLiteral("Article"), d->findUnusedId()));
@@ -1084,7 +1059,7 @@ void KBibTeXPart::fileExternallyChange(const QString &path)
         return;
     /// Should never happen: triggering this slot for filenames not being the opened file
     if (path != url().toLocalFile()) {
-        qCWarning(LOG_KBIBTEX_PARTS) << "Got file modification warning for wrong file: " << path << "!=" << url().toLocalFile();
+        qCWarning(LOG_KBIBTEX_PART) << "Got file modification warning for wrong file: " << path << "!=" << url().toLocalFile();
         return;
     }
 
@@ -1092,7 +1067,7 @@ void KBibTeXPart::fileExternallyChange(const QString &path)
     if (!path.isEmpty())
         d->fileSystemWatcher.removePath(path);
     else
-        qCWarning(LOG_KBIBTEX_PARTS) << "No filename to stop watching";
+        qCWarning(LOG_KBIBTEX_PART) << "No filename to stop watching";
 
     if (KMessageBox::warningContinueCancel(widget(), i18n("The file '%1' has changed on disk.\n\nReload file or ignore changes on disk?", path), i18n("File changed externally"), KGuiItem(i18n("Reload file"), QIcon::fromTheme(QStringLiteral("edit-redo"))), KGuiItem(i18n("Ignore on-disk changes"), QIcon::fromTheme(QStringLiteral("edit-undo")))) == KMessageBox::Continue) {
         d->openFile(QUrl::fromLocalFile(path), path);
@@ -1104,8 +1079,6 @@ void KBibTeXPart::fileExternallyChange(const QString &path)
         if (!path.isEmpty())
             d->fileSystemWatcher.addPath(path);
         else
-            qCWarning(LOG_KBIBTEX_PARTS) << "path is Empty";
+            qCWarning(LOG_KBIBTEX_PART) << "path is Empty";
     }
 }
-
-#include "part.moc"
