@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,68 +12,51 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_PART_PART_H
 #define KBIBTEX_PART_PART_H
 
-#include <kparts/part.h>
-
 #include <QObject>
 
-#include "notificationhub.h"
-#include "partwidget.h"
+#include <KParts/Part>
+#include <KParts/ReadWritePart>
+#include <KAboutData>
+
+#include <NotificationHub>
+#include <file/PartWidget>
 
 class KBibTeXPart : public KParts::ReadWritePart, private NotificationListener
 {
     Q_OBJECT
 
     friend class KBibTeXBrowserExtension;
-    friend class KBibTeXPartAdaptor;
 
 public:
-    KBibTeXPart(QWidget *parentWidget, QObject *parent, bool browserViewWanted);
-    virtual ~KBibTeXPart();
+    KBibTeXPart(QWidget *parentWidget, QObject *parent, const KAboutData &componentData);
+    ~KBibTeXPart() override;
 
-    void setModified(bool modified);
+    void setModified(bool modified) override;
 
-    virtual void notificationEvent(int eventId);
+    void notificationEvent(int eventId) override;
 
 protected:
-    virtual bool openFile();
-    virtual bool saveFile();
+    bool openFile() override;
+    bool saveFile() override;
 
 protected:
-    /*
-      protected Q_SLOTS: // action slots
-        void onSelectAll();
-        void onUnselect();
-        void onSetCoding( int Coding );
-        void onSetEncoding( int Encoding );
-        void onSetShowsNonprinting( bool on );
-        void onSetResizeStyle( int Style );
-        void onToggleOffsetColumn( bool on );
-        void onToggleValueCharColumns( int VisibleColunms );
-    */
-
-    /*
-      private Q_SLOTS:
-        // used to catch changes in the bytearray widget
-        void onSelectionChanged( bool HasSelection );
-    */
+    void setupActions();
 
 protected slots:
     bool documentSave();
     bool documentSaveAs();
     bool documentSaveCopyAs();
     void elementViewDocument();
-    void elementViewDocumentMenu(QObject *);
     void elementFindPDF();
     void applyDefaultFormatString();
 
 private slots:
-    void newElementTriggered(int event);
     void newEntryTriggered();
     void newMacroTriggered();
     void newCommentTriggered();
