@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,29 +12,37 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_PART_PARTFACTORY_H
 #define KBIBTEX_PART_PARTFACTORY_H
 
-#include <kparts/factory.h>
+#include <KPluginFactory>
 
-class KComponentData;
-
-class KBibTeXPartFactory : public KParts::Factory
+class KBibTeXPartFactory : public KPluginFactory
 {
     Q_OBJECT
+    Q_PLUGIN_METADATA(IID KPluginFactory_iid FILE "kbibtexpart.json")
+    Q_INTERFACES(KPluginFactory)
 
 public:
     KBibTeXPartFactory();
-    virtual ~KBibTeXPartFactory();
+    ~KBibTeXPartFactory() override;
 
-public:
-    virtual KParts::Part *createPartObject(QWidget *parentWidget, QObject *parent, const char *classname, const QStringList &args);
+protected:
 
-public:
-    static const KComponentData &componentData();
+    /**
+     * From KPluginFactory's documentation: "You may reimplement it to
+     * provide a very flexible factory. This is especially useful to
+     * provide generic factories for plugins implemeted using a scripting
+     * language."
+     */
+    QObject *create(const char *iface, QWidget *parentWidget, QObject *parent, const QVariantList &args, const QString &keyword) override;
+
+private:
+    class Private;
+    Private *const d;
 };
 
 #endif // KBIBTEX_PART_PARTFACTORY_H
