@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,10 +30,9 @@
 #include <QMenuBar>
 #include <QStackedWidget>
 #include <QDockWidget>
-#include <QDebug>
 #include <QPushButton>
+#include <QComboBox>
 #include <QMutex>
-#include <QMimeDatabase>
 #include <QMimeType>
 #include <QIcon>
 #ifdef HAVE_WEBENGINEWIDGETS
@@ -44,10 +43,15 @@
 #endif // HAVE_WEBKITWIDGETS
 #endif // HAVE_WEBENGINEWIDGETS
 
+#include <kio_version.h>
 #include <KLocalizedString>
-#include <KComboBox>
 #include <KJobWidgets>
+#if KIO_VERSION >= 0x054700 // >= 5.71.0
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
+#else // < 5.71.0
 #include <KRun>
+#endif // KIO_VERSION >= 0x054700
 #include <KMimeTypeTrader>
 #include <KService>
 #include <KParts/Part>
@@ -59,17 +63,16 @@
 #include <KActionCollection>
 #include <KSharedConfig>
 #include <KConfigGroup>
-#include <kio_version.h>
 
-#include "kbibtex.h"
-#include "element.h"
-#include "entry.h"
-#include "file.h"
-#include "fileinfo.h"
+#include <KBibTeX>
+#include <Element>
+#include <Entry>
+#include <File>
+#include <FileInfo>
 #include "logging_program.h"
 
-ImageLabel::ImageLabel(const QString &text, QWidget *parent, Qt::WindowFlags f)
-        : QLabel(text, parent, f)
+ImageLabel::ImageLabel(const QString &text, QWidget *parent)
+        : QLabel(text, parent)
 {
     /// nothing
 }
@@ -139,7 +142,7 @@ private:
     int swpMessage, swpOkular, swpHTML;
 
 public:
-    KComboBox *urlComboBox;
+    QComboBox *urlComboBox;
     QPushButton *onlyLocalFilesButton;
     QList<KIO::StatJob *> runningJobs;
     QSharedPointer<const Entry> entry;
@@ -185,7 +188,7 @@ public:
         sp.setVerticalPolicy(QSizePolicy::MinimumExpanding);
         onlyLocalFilesButton->setSizePolicy(sp);
 
-        urlComboBox = new KComboBox(false, p);
+        urlComboBox = new QComboBox(p);
         innerLayout->addWidget(urlComboBox, 1);
 
         externalViewerButton = new QPushButton(QIcon::fromTheme(QStringLiteral("document-open")), QString(), p);
@@ -257,8 +260,12 @@ public:
 
         loadState();
 
-        connect(externalViewerButton, &QPushButton::clicked, p, &DocumentPreview::openExternally);
-        connect(urlComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated), p, &DocumentPreview::comboBoxChanged);
+        connect(externalViewerButton, &QPushButton::clicked, p, [this]() {
+            openExternally();
+        });
+        connect(urlComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated), p, [this](int index) {
+            comboBoxChanged(index);
+        });
         connect(onlyLocalFilesButton, &QPushButton::toggled, p, &DocumentPreview::onlyLocalFilesChanged);
     }
 
@@ -329,13 +336,13 @@ public:
 
         /// do not load external reference if widget is hidden
         if (isVisible()) {
-            const auto urlList = FileInfo::entryUrls(entry, baseUrl, FileInfo::TestExistenceYes);
+            const auto urlList = FileInfo::entryUrls(entry, baseUrl, FileInfo::TestExistence::Yes);
             for (const QUrl &url : urlList) {
                 bool isLocal = KBibTeX::isLocalOrRelative(url);
                 anyRemote |= !isLocal;
                 if (!onlyLocalFilesButton->isChecked() && !isLocal) continue;
 
-                KIO::StatJob *job = KIO::stat(url, KIO::StatJob::SourceSide, 3, KIO::HideProgressInfo);
+                KIO::StatJob *job = KIO::mostLocalUrl(url, KIO::HideProgressInfo);
                 runningJobs << job;
                 KJobWidgets::setWindow(job, p);
                 connect(job, &KIO::StatJob::result, p, &DocumentPreview::statFinished);
@@ -542,11 +549,13 @@ public:
         QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
         const QString mimeTypeName = mimeType.name();
         /// Ask KDE subsystem to open url in viewer matching mime type
-#if KIO_VERSION < 0x051f00 // < 5.31.0
-        KRun::runUrl(url, mimeTypeName, p, false, false);
-#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+#if KIO_VERSION < 0x054700 // < 5.71.0
         KRun::runUrl(url, mimeTypeName, p, KRun::RunFlags());
-#endif // KIO_VERSION < 0x051f00
+#else // KIO_VERSION < 0x054700 // >= 5.71.0
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimeTypeName);
+        job->setUiDelegate(new KIO::JobUiDelegate());
+        job->start();
+#endif // KIO_VERSION < 0x054700
     }
 
     UrlInfo urlMetaInfo(const QUrl &url) {
@@ -560,14 +569,7 @@ public:
             return result;
         }
 
-        QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
-        // FIXME accuracy, necessary:
-        /*
-        if (accuracy < 50) {
-        QMimeDatabase db;
-            mimeType = db.mimeTypeForFile(url.fileName());
-        }
-        */
+        const QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
         result.mimeType = mimeType.name();
         result.icon = QIcon::fromTheme(mimeType.iconName());
 
@@ -619,7 +621,9 @@ const QString DocumentPreview::DocumentPreviewPrivate::onlyLocalFilesCheckConfig
 DocumentPreview::DocumentPreview(QDockWidget *parent)
         : QWidget(parent), d(new DocumentPreviewPrivate(this))
 {
-    connect(parent, &QDockWidget::visibilityChanged, this, &DocumentPreview::visibilityChanged);
+    connect(parent, &QDockWidget::visibilityChanged, this, [this]() {
+        d->update();
+    });
 }
 
 DocumentPreview::~DocumentPreview()
@@ -633,11 +637,6 @@ void DocumentPreview::setElement(QSharedPointer<Element> element, const File *)
     d->update();
 }
 
-void DocumentPreview::openExternally()
-{
-    d->openExternally();
-}
-
 void DocumentPreview::setBibTeXUrl(const QUrl &url)
 {
     d->baseUrl = url;
@@ -649,16 +648,6 @@ void DocumentPreview::onlyLocalFilesChanged()
     d->update();
 }
 
-void DocumentPreview::visibilityChanged(bool)
-{
-    d->update();
-}
-
-void DocumentPreview::comboBoxChanged(int index)
-{
-    d->comboBoxChanged(index);
-}
-
 void DocumentPreview::statFinished(KJob *kjob)
 {
     KIO::StatJob *job = static_cast<KIO::StatJob *>(kjob);
@@ -707,11 +696,13 @@ void DocumentPreview::linkActivated(const QString &link)
             QMimeType mimeType = FileInfo::mimeTypeForUrl(urlToOpen);
             const QString mimeTypeName = mimeType.name();
             /// Ask KDE subsystem to open url in viewer matching mime type
-#if KIO_VERSION < 0x051f00 // < 5.31.0
-            KRun::runUrl(urlToOpen, mimeTypeName, this, false, false);
-#else // KIO_VERSION < 0x051f00 // >= 5.31.0
+#if KIO_VERSION < 0x054700 // < 5.71.0
             KRun::runUrl(urlToOpen, mimeTypeName, this, KRun::RunFlags());
-#endif // KIO_VERSION < 0x051f00
+#else // KIO_VERSION < 0x054700 // >= 5.71.0
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(urlToOpen, mimeTypeName);
+            job->setUiDelegate(new KIO::JobUiDelegate());
+            job->start();
+#endif // KIO_VERSION < 0x054700
         }
     }
 }
