@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,12 +25,12 @@
 #include <KLocalizedString>
 #include <KIconLoader>
 
-#include "file.h"
-#include "clipboard.h"
-#include "fileview.h"
-#include "filedelegate.h"
-#include "models/filemodel.h"
-#include "idsuggestions.h"
+#include <File>
+#include <file/Clipboard>
+#include <file/FileView>
+#include <file/FileDelegate>
+#include <models/FileModel>
+#include <IdSuggestions>
 #include "logging_program.h"
 
 class SearchResults::SearchResultsPrivate
@@ -179,7 +179,7 @@ bool SearchResults::insertElement(QSharedPointer<Element> element)
 
 void SearchResults::documentSwitched(FileView *oldEditor, FileView *newEditor)
 {
-    Q_UNUSED(oldEditor);
+    Q_UNUSED(oldEditor)
     d->mainEditor = newEditor;
     updateGUI();
 }
