@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,11 +12,11 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#ifndef KBIBTEX_PROGRAM_VALUELIST_H
-#define KBIBTEX_PROGRAM_VALUELIST_H
+#ifndef KBIBTEX_PROGRAM_DOCKLET_VALUELIST_H
+#define KBIBTEX_PROGRAM_DOCKLET_VALUELIST_H
 
 #include <QWidget>
 #include <QModelIndex>
@@ -31,7 +31,7 @@ class ValueList : public QWidget
 
 public:
     explicit ValueList(QWidget *parent);
-    ~ValueList();
+    ~ValueList() override;
 
     void setFileView(FileView *fileView);
 
@@ -39,7 +39,7 @@ public slots:
     void update();
 
 protected slots:
-    void resizeEvent(QResizeEvent *e);
+    void resizeEvent(QResizeEvent *e) override;
 
 private slots:
     void listItemActivated(const QModelIndex &);
@@ -50,7 +50,6 @@ private slots:
     void deleteAllOccurrences();
     void showCountColumnToggled();
     void sortByCountToggled();
-    void delayedResize();
     void columnsChanged();
     void editorSelectionChanged();
     void editorDestroyed();
@@ -61,4 +60,4 @@ private:
     ValueListPrivate *d;
 };
 
-#endif // KBIBTEX_PROGRAM_VALUELIST_H
+#endif // KBIBTEX_PROGRAM_DOCKLET_VALUELIST_H
