@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,15 +25,15 @@
 #include <QAbstractItemModel>
 #include <QRadioButton>
 #include <QPushButton>
-#include <QDebug>
-#include <KLineEdit>
+#include <QPointer>
+#include <QLineEdit>
+#include <QComboBox>
 
 #include <KLocalizedString>
-#include <KComboBox>
 #include <KWallet/KWallet>
 #include <KMessageBox>
 
-#include "element.h"
+#include <Element>
 #include "searchresults.h"
 #include "zotero/collectionmodel.h"
 #include "zotero/collection.h"
@@ -43,6 +43,7 @@
 #include "zotero/tagmodel.h"
 #include "zotero/api.h"
 #include "zotero/oauthwizard.h"
+#include "logging_program.h"
 
 using KWallet::Wallet;
 
@@ -66,12 +67,12 @@ public:
     QTabWidget *tabWidget;
     QTreeView *collectionBrowser;
     QListView *tagBrowser;
-    KLineEdit *lineEditNumericUserId;
-    KLineEdit *lineEditApiKey;
+    QLineEdit *lineEditNumericUserId;
+    QLineEdit *lineEditApiKey;
     QRadioButton *radioPersonalLibrary;
     QRadioButton *radioGroupLibrary;
     bool comboBoxGroupListInitialized;
-    KComboBox *comboBoxGroupList;
+    QComboBox *comboBoxGroupList;
 
     QCursor nonBusyCursor;
 
@@ -115,7 +116,7 @@ public:
         gridLayout->addWidget(radioPersonalLibrary, 0, 0, 1, 2);
         radioGroupLibrary = new QRadioButton(i18n("Group library"), container);
         gridLayout->addWidget(radioGroupLibrary, 1, 0, 1, 2);
-        comboBoxGroupList = new KComboBox(false, container);
+        comboBoxGroupList = new QComboBox(container);
         gridLayout->addWidget(comboBoxGroupList, 2, 1, 1, 1);
         QSizePolicy sizePolicy = comboBoxGroupList->sizePolicy();
         sizePolicy.setHorizontalPolicy(QSizePolicy::MinimumExpanding);
@@ -125,7 +126,9 @@ public:
         comboBoxGroupList->addItem(i18n("No groups available"));
         connect(radioGroupLibrary, &QRadioButton::toggled, p, &ZoteroBrowser::radioButtonsToggled);
         connect(radioPersonalLibrary, &QRadioButton::toggled, p, &ZoteroBrowser::radioButtonsToggled);
-        connect(comboBoxGroupList, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &ZoteroBrowser::groupListChanged);
+        connect(comboBoxGroupList, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, [this]() {
+            needToApplyCredentials = true;
+        });
 
         containerLayout->addStretch(10);
 
@@ -133,17 +136,17 @@ public:
         QFormLayout *containerForm = new QFormLayout();
         containerLayout->addLayout(containerForm, 1);
         containerForm->setMargin(0);
-        lineEditNumericUserId = new KLineEdit(container);
+        lineEditNumericUserId = new QLineEdit(container);
         lineEditNumericUserId->setSizePolicy(sizePolicy);
         lineEditNumericUserId->setReadOnly(true);
         containerForm->addRow(i18n("Numeric user id:"), lineEditNumericUserId);
-        connect(lineEditNumericUserId, &KLineEdit::textChanged, p, &ZoteroBrowser::invalidateGroupList);
+        connect(lineEditNumericUserId, &QLineEdit::textChanged, p, &ZoteroBrowser::invalidateGroupList);
 
-        lineEditApiKey = new KLineEdit(container);
+        lineEditApiKey = new QLineEdit(container);
         lineEditApiKey->setSizePolicy(sizePolicy);
         lineEditApiKey->setReadOnly(true);
         containerForm->addRow(i18n("API key:"), lineEditApiKey);
-        connect(lineEditApiKey, &KLineEdit::textChanged, p, &ZoteroBrowser::invalidateGroupList);
+        connect(lineEditApiKey, &QLineEdit::textChanged, p, &ZoteroBrowser::invalidateGroupList);
 
         QBoxLayout *containerButtonLayout = new QHBoxLayout();
         containerLayout->addLayout(containerButtonLayout, 0);
@@ -303,7 +306,7 @@ bool ZoteroBrowser::applyCredentials()
         d->api.clear();
 
         const bool makeGroupRequest = d->radioGroupLibrary->isChecked() && groupId > 0;
-        d->api = QSharedPointer<Zotero::API>(new Zotero::API(makeGroupRequest ? Zotero::API::GroupRequest : Zotero::API::UserRequest, makeGroupRequest ? groupId : userId, d->lineEditApiKey->text(), this));
+        d->api = QSharedPointer<Zotero::API>(new Zotero::API(makeGroupRequest ? Zotero::API::RequestScope::Group : Zotero::API::RequestScope::User, makeGroupRequest ? groupId : userId, d->lineEditApiKey->text(), this));
         d->items = new Zotero::Items(d->api, this);
         d->tags = new Zotero::Tags(d->api, this);
         d->tagModel = new Zotero::TagModel(d->tags, this);
@@ -349,7 +352,7 @@ void ZoteroBrowser::retrieveGroupList() {
         d->groups->deleteLater();
         d->api.clear();
 
-        d->api = QSharedPointer<Zotero::API>(new Zotero::API(Zotero::API::UserRequest, userId, d->lineEditApiKey->text(), this));
+        d->api = QSharedPointer<Zotero::API>(new Zotero::API(Zotero::API::RequestScope::User, userId, d->lineEditApiKey->text(), this));
         d->groups = new Zotero::Groups(d->api, this);
 
         connect(d->groups, &Zotero::Groups::finishedLoading, this, &ZoteroBrowser::gotGroupList);
@@ -407,13 +410,13 @@ void ZoteroBrowser::readOAuthCredentials(bool ok) {
                     updateButtons();
                     retrieveGroupList();
                 } else
-                    qWarning() << "Failed to locate Zotero Id and/or API key in KWallet";
+                    qCWarning(LOG_KBIBTEX_PROGRAM) << "Failed to locate Zotero Id and/or API key in KWallet";
             } else
-                qWarning() << "Failed to access Zotero data in KWallet";
+                qCWarning(LOG_KBIBTEX_PROGRAM) << "Failed to access Zotero data in KWallet";
         } else
-            qDebug() << "No Zotero credentials stored in KWallet";
+            qCDebug(LOG_KBIBTEX_PROGRAM) << "No Zotero credentials stored in KWallet";
     } else
-        qWarning() << "Accessing KWallet to sync API key did not succeed";
+        qCWarning(LOG_KBIBTEX_PROGRAM) << "Accessing KWallet to sync API key did not succeed";
     reenableWidget();
 }
 
@@ -425,9 +428,9 @@ void ZoteroBrowser::writeOAuthCredentials(bool ok) {
         map.insert(ZoteroBrowser::Private::walletKeyZoteroId, d->lineEditNumericUserId->text());
         map.insert(ZoteroBrowser::Private::walletKeyZoteroApiKey, d->lineEditApiKey->text());
         if (d->wallet->writeMap(ZoteroBrowser::Private::walletEntryKBibTeXZotero, map) != 0)
-            qWarning() << "Writing API key to KWallet failed";
+            qCWarning(LOG_KBIBTEX_PROGRAM) << "Writing API key to KWallet failed";
     } else
-        qWarning() << "Accessing KWallet to sync API key did not succeed";
+        qCWarning(LOG_KBIBTEX_PROGRAM) << "Accessing KWallet to sync API key did not succeed";
     reenableWidget();
 }
 
