@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -75,7 +75,6 @@ private slots:
     void addToFavorites();
     void removeFromFavorites();
     void openFile();
-    void openFileWithService(int i);
     void closeFile();
 
 protected:
@@ -91,9 +90,10 @@ class DocumentList : public QTabWidget
     Q_OBJECT
 
 public:
-    enum Category { OpenFiles = 0, RecentFiles = 1, Favorites = 2 };
+    enum class Category { OpenFiles = 0, RecentFiles = 1, Favorites = 2 };
 
     explicit DocumentList(QWidget *parent = nullptr);
+    ~DocumentList();
 
 signals:
     void openFile(const QUrl &url);
