@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,6 @@
 #include <QFileInfo>
 #include <QWidget>
 #include <QUrl>
-#include <QDebug>
 #include <QApplication>
 
 #include <KLocalizedString>
@@ -34,7 +33,7 @@
 #include <KParts/ReadOnlyPart>
 #include <KParts/ReadWritePart>
 
-#include "fileimporterpdf.h"
+#include <FileImporterPDF>
 #include "logging_program.h"
 
 class OpenFileInfo::OpenFileInfoPrivate
@@ -60,7 +59,7 @@ public:
     QUrl url;
 
     OpenFileInfoPrivate(OpenFileInfoManager *openFileInfoManager, const QUrl &url, const QString &mimeType, OpenFileInfo *p)
-        :  m_counter(-1), p(p), part(nullptr), internalServicePtr(KService::Ptr()), internalWidgetParent(nullptr), flags(nullptr) {
+        :  m_counter(-1), p(p), part(nullptr), internalServicePtr(KService::Ptr()), internalWidgetParent(nullptr) {
         this->openFileInfoManager = openFileInfoManager;
         this->url = url;
         if (this->url.isValid() && this->url.scheme().isEmpty())
@@ -78,7 +77,7 @@ public:
     }
 
     KParts::ReadOnlyPart *createPart(QWidget *newWidgetParent, KService::Ptr newServicePtr = KService::Ptr()) {
-        if (!p->flags().testFlag(OpenFileInfo::Open)) {
+        if (!p->flags().testFlag(OpenFileInfo::StatusFlag::Open)) {
             qCWarning(LOG_KBIBTEX_PROGRAM) << "Cannot create part for a file which is not open";
             return nullptr;
         }
@@ -112,12 +111,12 @@ public:
             qCDebug(LOG_KBIBTEX_PROGRAM) << "XDG_DATA_DIRS=" << getenv("XDG_DATA_DIRS");
             qCDebug(LOG_KBIBTEX_PROGRAM) << "QT_PLUGIN_PATH=" << getenv("QT_PLUGIN_PATH");
             qCDebug(LOG_KBIBTEX_PROGRAM) << "KDEDIRS=" << getenv("KDEDIRS");
-            qCCritical(LOG_KBIBTEX_PROGRAM) << "Cannot find service to handle mimetype " << mimeType << endl;
+            qCCritical(LOG_KBIBTEX_PROGRAM) << "Cannot find service to handle mimetype " << mimeType;
             return nullptr;
         }
 
         QString errorString;
-        part = newServicePtr->createInstance<KParts::ReadWritePart>(newWidgetParent, (QObject *)newWidgetParent, QVariantList(), &errorString);
+        part = newServicePtr->createInstance<KParts::ReadWritePart>(newWidgetParent, qobject_cast<QObject *>(newWidgetParent), QVariantList(), &errorString);
         if (part == nullptr) {
             qCDebug(LOG_KBIBTEX_PROGRAM) << "PATH=" << getenv("PATH");
             qCDebug(LOG_KBIBTEX_PROGRAM) << "LD_LIBRARY_PATH=" << getenv("LD_LIBRARY_PATH");
@@ -126,7 +125,7 @@ public:
             qCDebug(LOG_KBIBTEX_PROGRAM) << "KDEDIRS=" << getenv("KDEDIRS");
             qCWarning(LOG_KBIBTEX_PROGRAM) << "Could not instantiate read-write part for service" << newServicePtr->name() << "(mimeType=" << mimeType << ", library=" << newServicePtr->library() << ", error msg=" << errorString << ")";
             /// creating a read-write part failed, so maybe it is read-only (like Okular's PDF viewer)?
-            part = newServicePtr->createInstance<KParts::ReadOnlyPart>(newWidgetParent, (QObject *)newWidgetParent, QVariantList(), &errorString);
+            part = newServicePtr->createInstance<KParts::ReadOnlyPart>(newWidgetParent, qobject_cast<QObject *>(newWidgetParent), QVariantList(), &errorString);
         }
         if (part == nullptr) {
             /// still cannot create part, must be error
@@ -138,13 +137,13 @@ public:
             /// open URL in part
             part->openUrl(url);
             /// update document list widget accordingly
-            p->addFlags(OpenFileInfo::RecentlyUsed);
-            p->addFlags(OpenFileInfo::HasName);
+            p->addFlags(OpenFileInfo::StatusFlag::RecentlyUsed);
+            p->addFlags(OpenFileInfo::StatusFlag::HasName);
         } else {
             /// initialize part with empty document
             part->openUrl(QUrl());
         }
-        p->addFlags(OpenFileInfo::Open);
+        p->addFlags(OpenFileInfo::StatusFlag::Open);
 
         internalServicePtr = newServicePtr;
         internalWidgetParent = newWidgetParent;
@@ -192,7 +191,7 @@ void OpenFileInfo::setUrl(const QUrl &url)
     if (d->url.scheme().isEmpty())
         qCWarning(LOG_KBIBTEX_PROGRAM) << "No scheme specified for URL" << d->url.toDisplayString();
     d->mimeType = FileInfo::mimeTypeForUrl(url).name();
-    addFlags(OpenFileInfo::HasName);
+    addFlags(OpenFileInfo::StatusFlag::HasName);
 }
 
 QUrl OpenFileInfo::url() const
@@ -271,9 +270,9 @@ OpenFileInfo::StatusFlags OpenFileInfo::flags() const
 void OpenFileInfo::setFlags(StatusFlags statusFlags)
 {
     /// disallow files without name or valid url to become favorites
-    if (!d->url.isValid() || !d->flags.testFlag(HasName)) statusFlags &= ~Favorite;
+    if (!d->url.isValid() || !d->flags.testFlag(StatusFlag::HasName)) statusFlags &= ~static_cast<int>(StatusFlag::Favorite);
     /// files that got opened are by definition recently used files
-    if (!d->url.isValid() && d->flags.testFlag(Open)) statusFlags &= RecentlyUsed;
+    if (!d->url.isValid() && d->flags.testFlag(StatusFlag::Open)) statusFlags &= StatusFlag::RecentlyUsed;
 
     bool hasChanged = d->flags != statusFlags;
     d->flags = statusFlags;
@@ -284,7 +283,7 @@ void OpenFileInfo::setFlags(StatusFlags statusFlags)
 void OpenFileInfo::addFlags(StatusFlags statusFlags)
 {
     /// disallow files without name or valid url to become favorites
-    if (!d->url.isValid() || !d->flags.testFlag(HasName)) statusFlags &= ~Favorite;
+    if (!d->url.isValid() || !d->flags.testFlag(StatusFlag::HasName)) statusFlags &= ~static_cast<int>(StatusFlag::Favorite);
 
     bool hasChanged = (~d->flags & statusFlags) > 0;
     d->flags |= statusFlags;
@@ -308,7 +307,7 @@ QDateTime OpenFileInfo::lastAccess() const
 void OpenFileInfo::setLastAccess(const QDateTime &dateTime)
 {
     d->lastAccessDateTime = dateTime;
-    emit flagsChanged(OpenFileInfo::RecentlyUsed);
+    emit flagsChanged(OpenFileInfo::StatusFlag::RecentlyUsed);
 }
 
 KService::List OpenFileInfo::listOfServices()
@@ -420,9 +419,9 @@ public:
     }
 
     void readConfig(QUrl &recentlyOpenURL) {
-        readConfig(OpenFileInfo::RecentlyUsed, configGroupNameRecentlyUsed, maxNumRecentlyUsedFiles);
-        readConfig(OpenFileInfo::Favorite, configGroupNameFavorites, maxNumFavoriteFiles);
-        readConfig(OpenFileInfo::Open, configGroupNameOpen, maxNumOpenFiles);
+        readConfig(OpenFileInfo::StatusFlag::RecentlyUsed, configGroupNameRecentlyUsed, maxNumRecentlyUsedFiles);
+        readConfig(OpenFileInfo::StatusFlag::Favorite, configGroupNameFavorites, maxNumFavoriteFiles);
+        readConfig(OpenFileInfo::StatusFlag::Open, configGroupNameOpen, maxNumOpenFiles);
 
         KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
         KConfigGroup cg(config, configGroupNameOpen);
@@ -431,9 +430,9 @@ public:
     }
 
     void writeConfig() {
-        writeConfig(OpenFileInfo::RecentlyUsed, configGroupNameRecentlyUsed, maxNumRecentlyUsedFiles);
-        writeConfig(OpenFileInfo::Favorite, configGroupNameFavorites, maxNumFavoriteFiles);
-        writeConfig(OpenFileInfo::Open, configGroupNameOpen, maxNumOpenFiles);
+        writeConfig(OpenFileInfo::StatusFlag::RecentlyUsed, configGroupNameRecentlyUsed, maxNumRecentlyUsedFiles);
+        writeConfig(OpenFileInfo::StatusFlag::Favorite, configGroupNameFavorites, maxNumFavoriteFiles);
+        writeConfig(OpenFileInfo::StatusFlag::Open, configGroupNameOpen, maxNumOpenFiles);
 
         KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
         KConfigGroup cg(config, configGroupNameOpen);
@@ -466,7 +465,7 @@ public:
                 ofi = p->open(fileUrl);
             }
             ofi->addFlags(statusFlag);
-            ofi->addFlags(OpenFileInfo::HasName);
+            ofi->addFlags(OpenFileInfo::StatusFlag::HasName);
             ofi->setLastAccess(QDateTime::fromString(cg.readEntry(QString(QStringLiteral("%1-%2")).arg(OpenFileInfo::OpenFileInfoPrivate::keyLastAccess).arg(i), ""), OpenFileInfo::OpenFileInfoPrivate::dateTimeFormat));
         }
     }
@@ -507,7 +506,7 @@ OpenFileInfoManager::OpenFileInfoManager(QObject *parent)
     QTimer::singleShot(250, this, [this, recentlyOpenURL]() {
         /// In case there is at least one file marked as 'open' but it is not yet actually open,
         /// set it as current file now. The file to be opened (identified by URL) should be
-        /// preferrably the file that was actively open at the end of last KBibTeX session.
+        /// preferably the file that was actively open at the end of last KBibTeX session.
         /// Slightly delaying the actually opening of files is necessary to give precendence
         /// to bibliography files passed as command line arguments (see program.cpp) over files
         /// that where open when the previous KBibTeX session was quit.
@@ -517,7 +516,7 @@ OpenFileInfoManager::OpenFileInfoManager(QObject *parent)
             OpenFileInfo *ofiToUse = nullptr;
             /// Go over the list of files that are flagged as 'open' ...
             for (auto *ofi : const_cast<const OpenFileInfoManager::OpenFileInfoList &>(d->openFileInfoList))
-                if (ofi->flags().testFlag(OpenFileInfo::Open) && (ofiToUse == nullptr || (recentlyOpenURL.isValid() && ofi->url() == recentlyOpenURL)))
+                if (ofi->flags().testFlag(OpenFileInfo::StatusFlag::Open) && (ofiToUse == nullptr || (recentlyOpenURL.isValid() && ofi->url() == recentlyOpenURL)))
                     ofiToUse = ofi;
             if (ofiToUse != nullptr)
                 setCurrentFile(ofiToUse);
@@ -577,8 +576,8 @@ bool OpenFileInfoManager::changeUrl(OpenFileInfo *openFileInfo, const QUrl &url)
     OpenFileInfo *previouslyContained = contains(url);
 
     /// check if old url differs from new url and old url is valid
-    if (previouslyContained != nullptr && previouslyContained->flags().testFlag(OpenFileInfo::Open) && previouslyContained != openFileInfo) {
-        qCWarning(LOG_KBIBTEX_PROGRAM) << "Open file with same URL already exists, forcefully closing it" << endl;
+    if (previouslyContained != nullptr && previouslyContained->flags().testFlag(OpenFileInfo::StatusFlag::Open) && previouslyContained != openFileInfo) {
+        qCWarning(LOG_KBIBTEX_PROGRAM) << "Open file with same URL already exists, forcefully closing it";
         close(previouslyContained);
     }
 
@@ -589,20 +588,20 @@ bool OpenFileInfoManager::changeUrl(OpenFileInfo *openFileInfo, const QUrl &url)
         /// current document was most probabily renamed (e.g. due to "Save As")
         /// add old URL to recently used files, but exclude the open files list
         OpenFileInfo *ofi = open(oldUrl); // krazy:exclude=syscalls
-        OpenFileInfo::StatusFlags statusFlags = (openFileInfo->flags() & (~OpenFileInfo::Open)) | OpenFileInfo::RecentlyUsed;
+        OpenFileInfo::StatusFlags statusFlags = (openFileInfo->flags() & ~static_cast<int>(OpenFileInfo::StatusFlag::Open)) | OpenFileInfo::StatusFlag::RecentlyUsed;
         ofi->setFlags(statusFlags);
     }
     if (previouslyContained != nullptr) {
         /// keep Favorite flag if set in file that have previously same URL
-        if (previouslyContained->flags().testFlag(OpenFileInfo::Favorite))
-            openFileInfo->setFlags(openFileInfo->flags() | OpenFileInfo::Favorite);
+        if (previouslyContained->flags().testFlag(OpenFileInfo::StatusFlag::Favorite))
+            openFileInfo->setFlags(openFileInfo->flags() | OpenFileInfo::StatusFlag::Favorite);
 
         /// remove the old entry with the same url has it will be replaced by the new one
         d->openFileInfoList.remove(d->openFileInfoList.indexOf(previouslyContained));
         previouslyContained->deleteLater();
-        OpenFileInfo::StatusFlags statusFlags = OpenFileInfo::Open;
-        statusFlags |= OpenFileInfo::RecentlyUsed;
-        statusFlags |= OpenFileInfo::Favorite;
+        OpenFileInfo::StatusFlags statusFlags = OpenFileInfo::StatusFlag::Open;
+        statusFlags |= OpenFileInfo::StatusFlag::RecentlyUsed;
+        statusFlags |= OpenFileInfo::StatusFlag::Favorite;
         emit flagsChanged(statusFlags);
     }
 
@@ -629,11 +628,11 @@ bool OpenFileInfoManager::close(OpenFileInfo *openFileInfo)
         if (!isClosing && ofi == openFileInfo && openFileInfo->close()) {
             isClosing = true;
             /// Mark file as closed (i.e. not open)
-            openFileInfo->removeFlags(OpenFileInfo::Open);
+            openFileInfo->removeFlags(OpenFileInfo::StatusFlag::Open);
             /// If file has a filename, remember as recently used
-            if (openFileInfo->flags().testFlag(OpenFileInfo::HasName))
-                openFileInfo->addFlags(OpenFileInfo::RecentlyUsed);
-        } else if (nextCurrent == nullptr && ofi->flags().testFlag(OpenFileInfo::Open))
+            if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::HasName))
+                openFileInfo->addFlags(OpenFileInfo::StatusFlag::RecentlyUsed);
+        } else if (nextCurrent == nullptr && ofi->flags().testFlag(OpenFileInfo::StatusFlag::Open))
             nextCurrent = ofi;
     }
 
@@ -655,14 +654,14 @@ bool OpenFileInfoManager::queryCloseAll()
     /// For each file known ...
     for (OpenFileInfo *openFileInfo : const_cast<const OpenFileInfoManager::OpenFileInfoList &>(d->openFileInfoList)) {
         /// Check only open file (ignore recently used, favorites, ...)
-        if (openFileInfo->flags().testFlag(OpenFileInfo::Open)) {
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::Open)) {
             if (openFileInfo->close()) {
                 /// If file could be closed without user canceling the operation ...
                 /// Mark file as closed (i.e. not open)
-                openFileInfo->removeFlags(OpenFileInfo::Open);
+                openFileInfo->removeFlags(OpenFileInfo::StatusFlag::Open);
                 /// If file has a filename, remember as recently used
-                if (openFileInfo->flags().testFlag(OpenFileInfo::HasName))
-                    openFileInfo->addFlags(OpenFileInfo::RecentlyUsed);
+                if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::HasName))
+                    openFileInfo->addFlags(OpenFileInfo::StatusFlag::RecentlyUsed);
                 /// Remember file as to be marked as open later
                 restoreLaterList.append(openFileInfo);
             } else {
@@ -681,7 +680,7 @@ bool OpenFileInfoManager::queryCloseAll()
         /// restarted again (assuming that this function was
         /// called when KBibTeX is exiting).
         for (OpenFileInfo *openFileInfo : const_cast<const OpenFileInfoManager::OpenFileInfoList &>(restoreLaterList)) {
-            openFileInfo->addFlags(OpenFileInfo::Open);
+            openFileInfo->addFlags(OpenFileInfo::StatusFlag::Open);
         }
 
         d->writeConfig();
@@ -704,7 +703,7 @@ void OpenFileInfoManager::setCurrentFile(OpenFileInfo *openFileInfo, KService::P
     d->currentFileInfo = openFileInfo;
 
     if (d->currentFileInfo != nullptr) {
-        d->currentFileInfo->addFlags(OpenFileInfo::Open);
+        d->currentFileInfo->addFlags(OpenFileInfo::StatusFlag::Open);
         d->currentFileInfo->setLastAccess();
     }
     if (hasChanged) {
@@ -714,28 +713,28 @@ void OpenFileInfoManager::setCurrentFile(OpenFileInfo *openFileInfo, KService::P
         emit currentChanged(openFileInfo, servicePtr);
 }
 
-OpenFileInfoManager::OpenFileInfoList OpenFileInfoManager::filteredItems(OpenFileInfo::StatusFlags required, OpenFileInfo::StatusFlags forbidden)
+OpenFileInfoManager::OpenFileInfoList OpenFileInfoManager::filteredItems(OpenFileInfo::StatusFlag required, OpenFileInfo::StatusFlags forbidden)
 {
     OpenFileInfoList result;
 
     for (OpenFileInfoList::Iterator it = d->openFileInfoList.begin(); it != d->openFileInfoList.end(); ++it) {
         OpenFileInfo *ofi = *it;
-        if ((ofi->flags() & required) == required && (ofi->flags() & forbidden) == 0)
+        if (ofi->flags().testFlag(required) && (ofi->flags() & forbidden) == 0)
             result << ofi;
     }
 
-    if (required == OpenFileInfo::RecentlyUsed)
-        qSort(result.begin(), result.end(), OpenFileInfoManagerPrivate::byLRULessThan);
-    else if (required == OpenFileInfo::Favorite || required == OpenFileInfo::Open)
-        qSort(result.begin(), result.end(), OpenFileInfoManagerPrivate::byNameLessThan);
+    if (required == OpenFileInfo::StatusFlag::RecentlyUsed)
+        std::sort(result.begin(), result.end(), OpenFileInfoManagerPrivate::byLRULessThan);
+    else if (required == OpenFileInfo::StatusFlag::Favorite || required == OpenFileInfo::StatusFlag::Open)
+        std::sort(result.begin(), result.end(), OpenFileInfoManagerPrivate::byNameLessThan);
 
     return result;
 }
 
 void OpenFileInfoManager::deferredListsChanged()
 {
-    OpenFileInfo::StatusFlags statusFlags = OpenFileInfo::Open;
-    statusFlags |= OpenFileInfo::RecentlyUsed;
-    statusFlags |= OpenFileInfo::Favorite;
+    OpenFileInfo::StatusFlags statusFlags = OpenFileInfo::StatusFlag::Open;
+    statusFlags |= OpenFileInfo::StatusFlag::RecentlyUsed;
+    statusFlags |= OpenFileInfo::StatusFlag::Favorite;
     emit flagsChanged(statusFlags);
 }
